AudioFileReader class

Inheritance

Constructors

AudioFileReader(File file)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onLoadAudio → EventStream<HTMLAudioElement>
final
onLoadData → EventStream<String?>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLoad(String? dataURL, String type) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited