BUIManifest class

Constructors

BUIManifest(ResourceContent? _resource)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getManifestContent() → Future<String?>
getManifestTree() → Future<Map?>
getViewProvider() → Future<BUIViewProvider?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(dynamic manifest) → BUIManifest?
parseTree<T>(String? manifestContent) → T?