ExplorerModel class

Constructors

ExplorerModel(ResourceConfig<ConfigDocument> resourceConfig)
ExplorerModel.fromURI(String resourceConfigUri)
factory

Properties

configDocument → ConfigDocument?
no setter
hashCode → int
The hash code for this object.
no setterinherited
modelType → String
no setter
resourceConfig → ResourceConfig<ConfigDocument>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri?
no setter
uriResolved → Future<Uri?>?
no setter

Methods

getConfigDocument() → Future<ConfigDocument?>
load() → Future<ConfigDocument?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveURL(String url) → Future<Uri?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(dynamic resourceConfigSource) → ExplorerModel?
fromJSON(dynamic json) → ExplorerModel?