JSONConfig class

Inheritance

Constructors

JSONConfig(dynamic resourceContent)
JSONConfig.withDocument(JSONConfigDocument doc)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isLoaded → bool
no setterinherited
onLoad → EventStream<String?>?
no setterinherited
resourceContent → ResourceContent?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri?
no setterinherited
uriResolved → Future<Uri?>?
no setterinherited

Methods

getDocument() → Future<JSONConfigDocument?>
inherited
getDocumentIfLoaded() → JSONConfigDocument?
inherited
load() → Future<JSONConfigDocument?>
inherited
loadDocument(String content) → JSONConfigDocument
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveURL(String url) → Future<Uri?>
inherited
setDocument(JSONConfigDocument doc) → void
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJSON(dynamic json) → JSONConfig?