PopupGroup class

Constructors

PopupGroup()

Properties

hashCode → int
The hash code for this object.
no setterinherited
popups → List<UIPopupMenu>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
contains(UIPopupMenu popup) → bool
hideAll([UIPopupMenu? ignorePopup]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(UIPopupMenu popup) → void
showAll([UIPopupMenu? ignorePopup]) → void
toString() → String
A string representation of this object.
inherited
unregister(UIPopupMenu popup) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited