TextProvider class

Constructors

TextProvider.fromElementProvider(ElementProvider? _elementProvider)
TextProvider.fromFunction(String _function()?)
TextProvider.fromIntlKey(IntlKey? _intlKey)
TextProvider.fromMessages(IntlMessages intlMessages, String key, {Map<String, dynamic>? variables, IntlVariablesProvider? variablesProvider})
TextProvider.fromObject(Object? _object)
TextProvider.fromText(String? _text)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleCall ↔ bool
getter/setter pair
text → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

accepts(dynamic text) → bool
from(Object? text) → TextProvider?