loadCount property
int
get
loadCount
Returns the number of loads performed for this asynchronous content.
Implementation
int get loadCount => _loadCount;
Returns the number of loads performed for this asynchronous content.
int get loadCount => _loadCount;