UINavigableComponent class abstract

Bones_UI base class for navigable components using routes.

Inheritance
Implementers
Available extensions

Constructors

UINavigableComponent(Object? parent, Iterable<String> routes, {dynamic componentClass, dynamic componentStyle, dynamic classes, dynamic classes2, dynamic style, dynamic style2, dynamic id, bool inline = true, bool renderOnConstruction = false})

Properties

clearParent → UIComponentClearParent?
finalinherited
componentInternals → UIComponentInternals
no setterinherited
constructing → bool?
no setterinherited
content → UIElement?
no setterinherited
currentRoute → String?
The current route rendered by this component.
no setter
currentRouteParameters → Map<String, String>?
The current route parameters used to rendered this component.
no setter
currentTitle ↔ String
getter/setter pair
dataSource → DataSource?
no setterinherited
dataSourceCall ↔ DataSourceCall?
getter/setter pairinherited
dataSourceCallString → String
no setterinherited
findRoutes ↔ bool?
getter/setter pair
globalID → int
finalinherited
hasDataSource → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ dynamic
getter/setter pairinherited
isInDOM → bool
no setterinherited
isLoadingUIAsyncContent → bool
no setterinherited
isRefreshFromExternalCall → bool
no setterinherited
isRendered → bool
no setterinherited
isRenderedWithError → bool
Returns true if current/last render had errors.
no setterinherited
isRendering → bool
no setterinherited
isShowing → bool
no setterinherited
localeChangedFromLastRender → bool
no setterinherited
List of routes (not hidden from menu) that this component can navigateTo.
no setter
Returns a Map of routes (not hidden from menu) and respective names.
no setter
onChange ↔ EventStream
getter/setter pairinherited
onChangeRoute → EventStream<String>
final
onRender → EventStream<UIComponent>
finalinherited
parent → UIElement?
no setterinherited
parentUIComponent → UIComponent?
The parent UIComponent.
no setterinherited
preserveRender ↔ bool
If true will preserve last render in next calls to render.
getter/setter pairinherited
preserveRenderCount → int
no setterinherited
refreshOnNavigate ↔ bool
getter/setter pairinherited
renderCount → int
no setterinherited
renderedElements → List?
no setterinherited
renderedElementsAsync → bool
no setterinherited
routes → List<String>
List of routes that this component can navigateTo.
no setter
routesAndNames → Map<String, String>
Returns a Map of routes and respective names.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subUIComponents → List<UIComponent>
Returns a List of sub UIComponent.
no setterinherited
subUIComponentsDeeply → Iterable<UIComponent>
Returns a List of sub UIComponent deeply in the tree.
no setterinherited
uiRoot → UIRoot?
Returns the UIRoot that is parent of this UIComponent instance, or null if it's not in an UIRoot components tree.
no setterinherited
uiRootComponent → UIRootComponent?
Returns the UIRootComponent that is parent of this UIComponent instance, or null if it's not in an UIRoot components tree.
no setterinherited

Methods

action(String action) → void
inherited
addTo(UIElement parent, {UIComponent? parentUIComponent}) → void
inherited
appendAttribute(String? name, dynamic value) → bool
inherited
appendAttributes(Iterable<DOMAttribute> attributes) → bool
inherited
appendClasses(Object? classes1, [Object? classes2]) → void
inherited
appendStyle(Object? style1, [Object? style2, Object? style3]) → void
inherited
appendToContent(List<UINode> nodes) → bool
inherited
applyData(dynamic data) → bool
inherited
callRender([bool clear = false]) → void
inherited
callRenderAndWait({Duration timeout = const Duration(seconds: 3)}) → Future<bool>
inherited
callRenderAsync() → void
inherited
canHandleNewRoute(String route) → bool
canNavigateTo(String route) → bool
Returns true if this instance can navigate to route.
clear({bool force = false, bool removeFromParent = false}) → void
Clears the component, removing the last rendered content.
inherited
clearAttribute(String? name) → bool
inherited
clearContent() → bool
inherited
clearPreservedRender() → void
Clears previous rendered elements. Only relevant if preserveRender is true.
inherited
click() → void
Calls: content.click
inherited
clone() → UIComponent?
inherited
configure() → void
Called by constructor, to configure this component.
inherited
configureClasses(Object? classes1, [Object? classes2, Object? componentClasses]) → void
inherited
configureID() → void
inherited
configureStyle(Object? style1, [Object? style2, Object? componentStyle]) → void
inherited
connectDataSource() → void
inherited
createContentElement(bool inline) → UIElement
inherited
delete() → void
inherited
deniedAccessRoute() → String?
inherited
deniedAccessRouteOfRoute(String route) → String?
Should return the route to redirect if route is not accessible.
deviceSizeChangedFromLastRender({double tolerance = 0.10, bool onlyWidth = false, bool onlyHeight = false}) → bool
inherited
ensureRendered([bool force = false]) → void
inherited
findChildDeep(FilterElement filter) → List<UIElement>
inherited
findChildrenDeep(String fieldName, {bool resolveUIComponents = true}) → MapEntry<String, Object>?
inherited
findInContentChildDeep(FilterElement filter) → UIElement?
inherited
findUIComponentByChild(UIElement? child) → UIComponent?
inherited
findUIComponentByContent(UIElement? content) → UIComponent?
inherited
findUIComponentByID(String id) → UIComponent?
inherited
fireEvent(String type, dynamic event, [List? params]) → void
inherited
focusField(String? fieldName) → bool
inherited
forEachEmptyFieldComponent(ForEachComponent f) → int
inherited
forEachEmptyFieldElement(ForEachElement f) → int
inherited
forEachFieldComponent(ForEachComponent f) → int
inherited
forEachFieldElement(ForEachElement f) → int
inherited
getAllRenderedElements(FilterRendered filter, [bool deep = false]) → List?
inherited
getAttribute(String? name) → dynamic
inherited
getComponentFieldName(Object obj) → String?
inherited
getContentChildren({FilterElement? filter, bool deep = true}) → List<UIElement>
inherited
getElementFieldName(UIElement element, {bool resolveUIComponents = true}) → String?
inherited
getEmptyFields() → List<String>
inherited
getField(String? fieldName, [String? def]) → String?
inherited
getFieldAs<T>(String? fieldName, [T? def]) → T?
inherited
getFieldComponent(String? fieldName, {bool resolveUIComponents = true}) → Object?
inherited
getFieldElement<E extends UIElement>(String? fieldName) → E?
inherited
getFieldElementByValue(String? fieldName, String value, {bool resolveUIComponents = true}) → UIElement?
inherited
getFieldElements(String? fieldName) → List<UIElement>
inherited
getFieldExtended<V>(String? fieldName, [V? def]) → V?
inherited
getFields({List<String>? fields, List<String>? ignoreFields, bool resolveUIComponents = true}) → Map<String, String?>
inherited
getFieldsComponents() → List<Object>
inherited
getFieldsComponentsMap({List<String>? fields, List<String>? ignoreFields}) → Map<String, Object>
inherited
getFieldsElements() → List<UIElement>
inherited
getFieldsElementsMap({List<String>? fields, List<String>? ignoreFields, bool resolveUIComponents = true}) → Map<String, UIElement>
inherited
getFieldsExtended({List<String>? fields, List<String>? ignoreFields}) → Map<String, Object?>
inherited
getFieldsGroupByPrefix<K, V>(String groupPrefix, {Map<String, String?>? fields, String keyDelimiter = '_', String keyPart(String a)?, K keyAs(String key)?, V? valueAs(String key)?, bool filter(K key, V? value)?}) → Map<K, V?>
inherited
getFieldsGroupCheckedKeys<K>(String groupPrefix, {Map<String, String?>? fields, String keyDelimiter = '_', String keyPart(String a)?, K keyAs(String key)?}) → List<K>
inherited
getFieldsGroupChecks<K>(String groupPrefix, {Map<String, String?>? fields, String keyDelimiter = '_', String keyPart(String a)?, K keyAs(String key)?, bool filter(K key, bool? value)?}) → Map<K, bool>
inherited
getFieldsGroupEntriesByPrefix<K, V>(String groupPrefix, {Map<String, String?>? fields, String keyDelimiter = '_', String keyPart(String a)?, K keyAs(String key)?, V? valueAs(String key)?, bool filter(K key, V? value)?}) → List<MapEntry<K, V?>>
inherited
getFieldsGroupKeysByPrefix<K>(String groupPrefix, {Map<String, String?>? fields, String keyDelimiter = '_', String keyPart(String a)?, K keyAs(String key)?, bool filter(K key, Object? value)?}) → List<K>
inherited
getFieldsGroupListByPrefix<K, V>(String groupPrefix, {Map<String, String?>? fields, String keyDelimiter = '_', String keyPart(String a)?, K keyAs(String key)?, V? valueAs(String key)?, bool filter(K key, V? value)?}) → Map<K, List<V>>
inherited
getFieldsGroupValuesByPrefix<V>(String groupPrefix, {Map<String, String?>? fields, String keyDelimiter = '_', String keyPart(String a)?, V? valueAs(String key)?, bool filter(Object key, V? value)?}) → List<V>
inherited
getFieldsNames() → List<String>
inherited
getPreviousRenderedFieldValue(String? fieldName) → dynamic
inherited
getRenderedElement(FilterRendered filter, [bool? deep]) → dynamic
inherited
getRenderedElementById(dynamic id, [bool deep = false]) → dynamic
inherited
getRenderedElementValueById(dynamic id, [bool deep = false]) → dynamic
inherited
getRenderedUIComponentById<T extends UIComponent>(dynamic id, [bool? deep]) → T?
inherited
getRenderedUIComponentByType<T>([bool? deep]) → List<T>
inherited
getRenderedUIComponents([bool? deep]) → Iterable<UIComponent>
inherited
getRenderedUIComponentsByIds<T extends UIComponent>(List ids, [bool? deep]) → List<UIComponent>
inherited
getRouteName(String route) → String?
Returns a route name.
hasEmptyField() → bool
inherited
hide() → void
Hide component.
inherited
insertTo(int index, UIElement parent, {UIComponent? parentUIComponent}) → void
inherited
isAccessible() → bool
inherited
isAccessibleRoute(String route) → bool
Should return true if route isAccessible.
isEmptyField(String? fieldName) → bool
inherited
isRouteHiddenFromMenu(String route) → bool
Returns true of route should be hidden from menu.
markRenderedWithError() → void
Marks current/last render with error.
inherited
Changes the current selected route, with parameters, of this UINavigableComponent.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChangeRoute() → void
onChildRendered(UIComponent child) → void
inherited
onPreConstruct() → void
Called in the beginning of constructor.
inherited
parseChildElementValue(UIElement? childElement, {UIComponent? childUiComponent, bool allowTextAsValue = true, bool resolveUIComponents = true}) → String?
inherited
posAsyncRender() → void
inherited
posRender() → void
Called after render.
inherited
preRender() → void
Called before render.
inherited
preRenderClear() → void
inherited
querySelector<E extends UIElement>(String? selectors) → E?
Alias to content.querySelector.
inherited
querySelectorAll<T extends UIElement>(String? selectors) → List<T>
Alias to content.querySelectorAll.
inherited
refresh({bool forceRender = false}) → void
Refreshes the component, calling render.
inherited
refreshDataSource() → void
inherited
refreshIfLocaleChanged() → void
inherited
refreshInternal() → void
inherited
registerEventListener(String type, UIEventListener listener) → void
inherited
registerInUIRoot() → void
Called by constructor to register this component in the UIRoot tree.
inherited
render() → dynamic
Renders the elements of this component.
override
renderError(dynamic error) → dynamic
Called when render returns a Future value, to render the content when Future has an error.
inherited
renderLoading() → dynamic
Called when render returns a Future value, to render the content while loading Future.
inherited
renderRoute(String? route, Map<String, String>? parameters) → dynamic
Called to render the route with parameters.
renderTestUI({int ms = 100}) → Future<int>

Available on UIComponent, provided by the TestUIComponentExtension extension

requestRefresh({Duration? delay}) → void
Requests a refresh using Future.microtask or Future.delayed.
inherited
resolveTextIntl(String text) → String
Resolves text {{intl:key}} messages.
inherited
select<E extends UIElement>(String? selectors) → E?

Available on UIComponent?, provided by the TestUIComponentNullableExtension extension

selectAll<E extends Element>(String? selectors) → List<E>

Available on UIComponent?, provided by the TestUIComponentNullableExtension extension

selectElement<E extends UIElement>(String? selectors) → E?
Alias to content.querySelector.
inherited
selectElements<T extends UIElement>(String? selectors) → List<T>
Alias to content.querySelectorAll.
inherited
selectElementsValues<T extends UIElement>(String? selectors) → Map<String, String?>
Alias to content.querySelectorAll.
inherited
selectExpected<E extends UIElement>(String? selectors) → E

Available on UIComponent?, provided by the TestUIComponentNullableExtension extension

setAttribute(String? name, dynamic value) → bool
inherited
setAttributes(Iterable<DOMAttribute> attributes) → bool
inherited
setContentNodes(List<UINode> nodes) → bool
inherited
setData(dynamic data) → bool
inherited
setField(String fieldName, dynamic value) → void
inherited
setID(Object? id) → void
inherited
setParent(UIElement parent, {UIComponent? parentUIComponent}) → UIElement?
Sets the parent UIElement.
inherited
setRoutes(List<String>? routes) → void
show() → void
Show component.
inherited
simplify({bool trim = true, bool collapseSapces = true, bool lowerCase = true, String nullValue = ''}) → String

Available on UIComponent?, provided by the TestUIComponentNullableExtension extension

toContentElements(dynamic rendered, {bool append = false, bool parseAttributes = true}) → List
inherited
toRenderableList(Object? list, [DOMContext<UINode>? domContext]) → List?
inherited
toString() → String
A string representation of this object.
inherited
updateRenderedFieldElementValue(UIElement fieldElem) → void
inherited
updateRenderedFieldValue(String fieldName) → void
inherited
updateRoutes([List<String>? foundRoutes]) → bool
waiteRender({Duration timeout = const Duration(seconds: 3)}) → Future<bool>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

componentClass → String
final