UINavigator class

Handles navigation and routes.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearDetachedNavigables({UINavigableComponent? ignore}) → void
Removes from navigables cache detached elements.
findElementNavigableRoutes(UIElement? element) → List<String>
Find in element tree nodes with attribute navigate.
findNavigable(String route) → UINavigableComponent?
Finds a UINavigableComponent that responds for route.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshNavigation([bool force = false]) → void
Refreshed the current route.
refreshNavigationAsync([bool force = false]) → void
Refreshed the current route asynchronously.
registerNavigable(UINavigableComponent navigable) → void
Registers a UINavigableComponent.
selectNavigables([UIElement? element]) → List<Element>
Returns List<UIElement> that are from navigable components.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

currentNavigation → Navigation?
Returns the current Navigation.
no setter
currentRoute → String?
Returns the current route.
no setter
currentRouteParameters → Map<String, String>?
Returns the current route parameters.
no setter
hasRoute → bool
Returns true if current location has a route entry.
no setter
initialNavigation → Navigation?
Returns the initial Navigation when browser window was open.
no setter
initialRoute → String?
Returns the initial route when browser window was open.
no setter
isOffline → bool
Returns true if this device is off-line.
no setter
isOnline → bool
Returns true if this device is online.
no setter
isSecureContext → bool
Returns true if this device is in secure contexts (HTTPS).
no setter
Returns all the known routes of registered navigables.
no setter
no setter
no setter
Returns a history list of Navigation.
no setter
onNavigate → EventStream<String>
EventStream for when navigation changes. Passes route name.
no setter
urlFilter ↔ String Function(String a)?
getter/setter pair

Static Methods

clearNavigateOnClick(HTMLElement element) → bool
equalsToCurrentRoute(String route, {Map<String, String>? parameters}) → bool
Returns true if route equals to currentRoute.
equalsToCurrentRouteParameters(Map<String, String>? parameters) → bool
Returns true if parameters are equals to currentRouteParameters.
get() → UINavigator
getCurrentRoute({String defaultRoute = ''}) → String
Returns the currentRoute or defaultRoute.
getNavigateOnClick(UIElement element) → String?
Returns the current navigate property of element.
Navigate using navigation do determine route and parameters.
Navigate asynchronously using navigation do determine route and parameters.
Register a onClick listener in element to navigate to route with parameters.
Navigate to a route with parameters or parametersProvider.
Navigate asynchronously to a route with parameters or parametersProvider.
Navigates to a main route (mainRouteLogged or mainRouteNotLogged) based in isLogged status and isLoggedRoute and isNotLoggedRoute checkers.