navigateToAsync static method

void navigateToAsync(
  1. String? route, {
  2. Map<String, String>? parameters,
  3. ParametersProvider? parametersProvider,
  4. bool force = false,
})

Navigate asynchronously to a route with parameters or parametersProvider.

force If true changes the route even if the current route is the same.

Implementation

static void navigateToAsync(String? route,
    {Map<String, String>? parameters,
    ParametersProvider? parametersProvider,
    bool force = false}) {
  get()._callNavigateToAsync(route, parameters, parametersProvider, force);
}