YAMLConfig class

Inheritance

Constructors

YAMLConfig(dynamic resourceContent)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isLoaded → bool
no setterinherited
onLoad → EventStream<String?>?
no setterinherited
resourceContent → ResourceContent?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri?
no setterinherited
uriResolved → Future<Uri?>?
no setterinherited

Methods

getDocument() → Future<YAMLConfigDocument?>
inherited
getDocumentIfLoaded() → YAMLConfigDocument?
inherited
load() → Future<YAMLConfigDocument?>
inherited
loadDocument(String content) → YAMLConfigDocument
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveURL(String url) → Future<Uri?>
inherited
setDocument(YAMLConfigDocument doc) → void
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited