YAMLConfigDocument class

Inheritance

Constructors

YAMLConfigDocument(YamlDocument document)
YAMLConfigDocument.load(String yaml)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asString() → String
override
asYamlNode() → YamlNode
get(String key, [dynamic def]) → dynamic
override
getAsBool(String key, [bool? def]) → bool?
inherited
getAsBoolList(String key, [List<bool>? def]) → List<bool>
inherited
getAsDouble(String key, [double? def]) → double?
inherited
getAsDoubleList(String key, [List<double>? def]) → List<double>
inherited
getAsInt(String key, [int? def]) → int?
inherited
getAsIntList(String key, [List<int>? def]) → List<int>
inherited
getAsList(String key, [List? def]) → List?
inherited
getAsMap(String key, [Map? def]) → Map?
inherited
getAsNum(String key, [num? def]) → num?
inherited
getAsNumList(String key, [List<num>? def]) → List<num>
inherited
getAsString(String key, [String? def]) → String?
inherited
getAsStringList(String key, [List<String>? def]) → List<String>
inherited
getPath(List<String> keys, [dynamic def]) → dynamic
inherited
getPathAsString(List<String> keys, [dynamic def]) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited