createWrapper method
Creates a wrapper for the given key and value.
Implementations typically store the wrapper in an internal key → wrapper structure before returning it.
Implementation
@override
SimpleFinalizerWrapper<V> createWrapper(K key, V value) => debug
? SimpleFinalizerWrapperDebug(key, value)
: SimpleFinalizerWrapper(value);