debug property

bool debug
final

Enables debug mode.

When true, created wrappers retain a weak reference to the associated key, allowing inspection for memory leak analysis. When false, a minimal wrapper is used.

Implementation

final bool debug;