getWrapper method
Returns the wrapper currently associated with key, or null
if no association exists.
Implementation
@override
SimpleFinalizerWrapper<V>? getWrapper(K key) => null;
Returns the wrapper currently associated with key, or null
if no association exists.
@override
SimpleFinalizerWrapper<V>? getWrapper(K key) => null;