remove method
Removes the association for key, if present.
Detaches the wrapper from the internal Finalizer to prevent the callback from firing in the future.
Returns the previously associated value, or null if none existed.
Implementation
@override
Never remove(K key) => throw UnsupportedError("Can't remove keys!");