Authorization class abstract

Represents a kind of HTTP Authorization.

Constructors

Authorization.fromCredential(Credential credential)
Constructs a AuthorizationStatic.
factory
Authorization.fromProvider(AuthorizationProvider provider)
Constructs a AuthorizationResolvable.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCredentialResolved → bool
Returns true if the Credential is already resolved.
no setter
isResolvingCredential → bool
Returns true if is in the process of Credential resolution.
no setter
isStaticCredential → bool
Returns true if the Credential is static (future calls to resolveCredential will return the same instance).
no setter
resolvedCredential → Credential?
Returns the resolved Credential.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryResolvedCredential → Credential?
Returns the resolved Credential or null if not resolved.
no setter
usesAuthorizationHeader → bool
Returns true if resolved Credential uses Authorization HTTP header.
no setter

Methods

copy() → Authorization
Copies this instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveCredential(HttpClient client, HttpError? lastError) → Future<Credential?>
Resolves the actual Credential for the HttpRequest. This method should cache the last resolved Credential and avoid unnecessary resolving procedures.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited