Credential class abstract

Abstract Credential for HttpRequest.

Constructors

Credential()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of the credential.
no setter
usesAuthorizationHeader → bool
If this credential uses the header Authorization.
no setter

Methods

buildAuthorizationHeaderLine() → String?
Builds the header Authorization.
buildBody(HttpRequestBody body) → HttpRequestBody?
Builds the HttpRequest body. Used by credentials that injects tokens/credentials in the body.
buildURL(String url) → String?
Builds the HttpRequest URL. Used by credentials that injects tokens/credentials in the URL.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited