DataCallHttp class

Represents a HttpCall to request data.

Inheritance

Constructors

DataCallHttp({String? baseURL, HttpClient? client, HttpMethod method = HttpMethod.GET, String path = '', bool fullPath = false, Object? parametersPattern, Object? body, int maxRetries = 0})
DataCallHttp.from(HttpCall config)
factory

Properties

body → Object?
finalinherited
client → HttpClient
finalinherited
fullPath → bool
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
maxRetries → int
finalinherited
method → HttpMethod
finalinherited
parametersPattern → Map<String, String>?
final
path → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Map<String, dynamic>? parameters, {Object? body, int? maxRetries}) → Future<HttpResponse?>
Performs a call, making the HTTP request.
inherited
callAndResolve(Map<String, dynamic>? parameters, {Object? body, int? maxRetries}) → Future
Performs a call, making the HTTP request, than resolves the response.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestHttpClient(HttpClient client, HttpMethod method, String path, bool fullPath, Map? parameters, Object? body) → Future<HttpResponse>
Method responsible to request the HttpClient.
override
resolveResponse(HttpResponse? response) → dynamic
Method responsible to resolve the response to a R value.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

toParametersPattern(Object? parametersPattern) → Map<String, String>?