DataSourceResolver<T> class

Wrapper to resolve a DataSource.

Properties

domain → String
no setter
hashCode → int
The hash code for this object.
no setteroverride
id → String?
final
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveDataSource() → DataSource<T>?
resolveDataSourceAsync([Duration? timeout]) → Future<DataSource<T>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override