DataSourceResponse<T> class

Constructors

DataSourceResponse(DataSourceOperation operation, Map<String, String>? parameters, List<T>? dataList, List<T>? result)

Properties

dataList → List<T>?
final
elapsedTime → int
no setter
hashCode → int
The hash code for this object.
no setteroverride
operation → DataSourceOperation
final
parameters → Map<String, String>?
final
result → List<T>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → int
final

Methods

isExpired(int timeout) → bool
isSameCall(DataSourceOperation operation, Map<String, String>? parameters, List? dataList) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override