Dimension class

Represents a width X height dimension.

Implemented types

Constructors

Dimension(int width, int height)

Properties

area → int
Area of the dimension.
no setter
hashCode → int
The hash code for this object.
no setteroverride
height → int
Height of the dimension.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
Width of the dimension.
final

Methods

compareTo(Dimension other) → int
Compares with other Dimension.area.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subtract(Dimension other, [bool maximumDifferences = false]) → int
Returns the difference between this and other, using width and height.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

parsers ↔ Set<Dimension? Function(Object? value)>
Extra parsers.
getter/setter pair

Static Methods

from(Object? dimension) → Dimension?
parse(String? wh, [Pattern? delimiter]) → Dimension?
Parsers wh String, trying to split with delimiter between 2 numbers in the string.