DynCallHttpExecutor<E> class

A DynCallExecutor for HTTP calls.

Inheritance

Constructors

DynCallHttpExecutor(HttpClient httpClient, HttpMethod method, String? path, {bool? fullPath, Map<String, String>? parametersMap, Map<String, String>? parametersStatic, Map<String, ParameterProvider>? parametersProviders, String? queryString, bool? noQueryString, Credential? authorization, List<String>? authorizationFields, Object? body, Object? bodyBuilder, String? bodyType, HTTPOutputValidator? outputValidator, HTTPOutputFilter? outputFilter, HTTPJSONOutputFilter? jsonOutputFilter, String? outputFilterPattern, HTTPOutputInterceptor<E>? outputInterceptor, E? errorResponse, int errorMaxRetries = 3, OnHttpError? onHttpError})

Properties

authorization ↔ Credential?
The Credential for the HTTP request.
getter/setter pair
authorizationFields ↔ List<String>?
Specify call parameters to use as authorizationFields.
getter/setter pair
body ↔ Object?
Body of the request.
getter/setter pair
bodyBuilder ↔ Object?
Body pattern for the request.
getter/setter pair
bodyType ↔ String?
Body type. Example: JSON.
getter/setter pair
errorMaxRetries ↔ int
Maximum number o retries for the call.
getter/setter pair
errorResponse ↔ E?
Call response in case of an error.
getter/setter pair
fullPath ↔ bool?
Call full path (to overwrite client basePath).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpClient ↔ HttpClient
The HTTP client.
getter/setter pair
jsonOutputFilter ↔ HTTPJSONOutputFilter?
Filter for the output (as JSON), to transform the request response to another JSON.
getter/setter pair
method ↔ HttpMethod
HTTP Method.
getter/setter pair
noQueryString ↔ bool?
If true will avoid use of queryString in request URL.
getter/setter pair
onHttpError ↔ OnHttpError?
In case of error what behavior to follow: OnHttpErrorAnswer
getter/setter pair
outputFilter ↔ HTTPOutputFilter?
Filter for the output (as String), to transform the request response to another String.
getter/setter pair
outputFilterPattern ↔ String?
Filter for the output, to transform the request response using a String pattern. See: buildStringPattern.
getter/setter pair
outputInterceptor ↔ HTTPOutputInterceptor<E>?
Function called for any output received. Useful for logs.
getter/setter pair
outputValidator ↔ HTTPOutputValidator?
Function to validate if the request output is valid.
getter/setter pair
parametersMap ↔ Map<String, String>?
Maps input to query parameters.
getter/setter pair
parametersProviders ↔ Map<String, ParameterProvider>?
Query parameters with values from ParameterProvider.
getter/setter pair
parametersStatic ↔ Map<String, String>?
Query parameters with static values.
getter/setter pair
path ↔ String?
Call path.
getter/setter pair
queryString ↔ String?
Forces the URI query string.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildAuthorization(Map<String, String?>? parameters) → Credential?
buildAuthorizationWithFields(Map<String, String?>? parameters) → Credential?
buildBody(Map<String, String?>? parameters, [Map<String, String?>? requestParameters]) → Object?
buildBodyType(String? body) → String?
buildParameters(Map<String, String?>? parameters) → Map<String, String?>?
buildURI<X>(DynCall<E, X> dynCall, Map<String, String?> callParameters) → String
override
call<X>(DynCall<E, X>? dynCall, Map<String, String?>? callParameters, SysProgressListener? onProgress) → Future<E?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCredential(DynCallCredential credential) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited