debug property

bool debug
final

Enables debug mode.

When true, wrappers retain an additional weak reference to the associated key, allowing inspection for memory leak analysis. When false, a lighter wrapper is used.

Implementation

final bool debug;