get method
V?
get(
- K key
Returns associated value if the key is still alive.
Implementation
V? get(K key) => _expando[key]?.value;
Returns associated value if the key is still alive.
V? get(K key) => _expando[key]?.value;