remove method
Removes the association for key, if present.
Detaches the wrapper from the internal Finalizer to prevent the callback from firing in the future.
Returns the previously associated value, or null if none existed.
Implementation
@override
V? remove(K key) {
var value = super.remove(key);
if (value != null) {
_expando[key] = null;
return value;
}
return null;
}