FinalizerValueWrapper<V extends Object> class abstract

A strongly typed wrapper used as a finalization token.

Implementations encapsulate a non-null value that will be delivered to user code when the associated key becomes unreachable and is garbage-collected.

This indirection allows attaching structured metadata to a Finalizer while keeping the actual value strongly typed.

Constructors

FinalizerValueWrapper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → V
The wrapped value associated with the finalizer.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited