Geolocation class

Represents a Geo Location in latitude and longitude.

Constructors

Geolocation(num _latitude, num _longitude)

Properties

hashCode → int
The hash code for this object.
no setterinherited
latitude → num
The latitude of the coordinate.
no setter
longitude → num
The longitude of the coordinate.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asPoint() → Point<num>
As Point(latitude , longitude).
googleMapsDirectionsURL(Geolocation destinationGeo) → String
Generates a Google Maps Directions URL with coordinates.
googleMapsURL() → String
Generates a Google Maps URL with coordinates.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
windowID(String prefix) → String
Generates a browser windoe ID with coordinates.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

geolocationFormat → RegExp
final

Static Methods

formatGeolocation(Point<num> geo) → String
formatLatitude(num lat) → String
formatLongitude(num long) → String
fromCoords(String? coords, [bool onlyWithCardinals = false]) → Geolocation?
parseLatitudeOrLongitudeValue(String? s, [bool onlyWithCardinals = false]) → num?