HttpBlob<B> class abstract

Constructors

HttpBlob(B blob, MimeType? mimeType)

Properties

blob → B
final
hashCode → int
The hash code for this object.
no setterinherited
mimeType → MimeType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readByteBuffer() → Future<ByteBuffer>
size() → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited