HttpClientInterceptor class abstract

An interceptor that can be used to filter requests and responses.

Constructors

HttpClientInterceptor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

filterRequest(HttpClient client, HttpMethod method, String url, Map<String, String>? headers) → FutureOr<String?>
Filters the request before submit.
filterResponse(HttpClient client, HttpResponse response) → FutureOr<HttpResponse?>
Filters the response before is returned by the client.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited