HttpRequester class

A Class able to do a HTTP request based in properties:

  • httpMethod: The HTTP Method name.
  • scheme: URL scheme.
  • host: URL Host.
  • path: URL path.
  • bodyType: The request body type.
  • body: The request body.
  • responseType: desired response type: JSON, JSONPaging

Constructors

HttpRequester(Map<String, Object?> config, [Map<String, Object?>? properties, HttpCache? httpCache])

Properties

baseURL → String
no setter
body → String?
no setter
bodyType → String?
no setter
config → MapProperties
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
no setter
httpCache ↔ HttpCache?
getter/setter pair
httpClient → HttpClient?
Returns HttpClient. Instantiates one if is null.
no setter
httpMethod → HttpMethod
no setter
parameters → Map<String, String?>?
no setter
path → String
no setter
properties → MapProperties
final
responseType → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String
no setter

Methods

doRequest() → Future
Does the request.
doRequestWithClient(HttpClient httpClient) → Future
Does the request using parameter httpClient.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited