InteractionCompleter class

Tracks interactions and after a delay, without interaction, triggers onComplete.

Constructors

InteractionCompleter(String name, {Duration? triggerDelay, Function? functionToTrigger, Duration? triggerDelayLimit})

Properties

fullInteractionElapsedTime → int?
no setter
functionToTrigger ↔ Function?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasInteractionNotTriggered → bool
no setter
hasTriggerDelayLimit → bool
no setter
interactionElapsedTime → int?
no setter
isTriggerScheduled → bool
no setter
lastInteractionParameters → List?
no setter
lastInteractionTime → int?
no setter
name → String
Name of this instance.
final
now → int
no setter
onComplete → EventStream<InteractionCompleter>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerDelay → Duration
The delay between interact and triggering. Delay starts/restarts on each interaction.
final
triggerDelayLimit → Duration?
The limit of delay between 1st interact and triggering. Delay starts in the 1st call to interact and is zeroed when the trigger is called.
final
triggerDelayMs → int
no setter

Methods

cancel() → void
Cancels any event scheduled to be triggered.
dispose() → void
cancel this instance and dispose any resource.
disposeLastInteractionParameters() → void
interact({dynamic noTriggering = false, List? interactionParameters, bool ignoreConsecutiveEqualsParameters = false}) → void
Marks an interaction and schedules delayed trigger.
log(String method, [List? parameters]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
triggerIfHasInteraction({List? interactionParameters}) → void
Triggers only if already has some interaction.
triggerNow({List? interactionParameters}) → void
Triggers immediately.

Operators

operator ==(Object other) → bool
The equality operator.
inherited