JSONBodyCredential class

A Credential that injects a JSON in the HttpRequest body.

Inheritance

Constructors

JSONBodyCredential(String field, dynamic authorization)

Properties

authorization → dynamic
Authorization JSON tree.
final
field → String?
JSON field name.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Returns jsonbody.
no setteroverride
usesAuthorizationHeader → bool
Returns false.
no setteroverride

Methods

buildAuthorizationHeaderLine() → String?
Builds the header Authorization.
override
buildBody(HttpRequestBody body) → HttpRequestBody
Builds the HttpRequest body with the Credential.
override
buildJSONAuthorizationBody(HttpRequestBody? body) → HttpRequestBody
buildJSONAuthorizationBodyJSON(HttpRequestBody? body) → String
buildURL(String url) → String
Won't change the parameter url.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited