id property

int id
final

Unique sequence identifier assigned by the owning manager.

Used as a tie-breaker in compareTo to provide a strict ordering between instances that share the same timestamp. Uniqueness is only guaranteed among references created by the same manager.

Implementation

final int id;