unixTimeMs property
int
get
unixTimeMs
Unix timestamp (milliseconds) of creation or of the most recent transition to a strong reference.
Implementation
int get unixTimeMs => _unixTimeMs;
Unix timestamp (milliseconds) of creation or of the most recent transition to a strong reference.
int get unixTimeMs => _unixTimeMs;