batchInterval property
Delay between batch processing. Default: 1 ms
Helps prevent long processing from blocking I/O, events, or UI updates by yielding time back to the event loop between batches.
Implementation
final Duration batchInterval;
Delay between batch processing. Default: 1 ms
Helps prevent long processing from blocking I/O, events, or UI updates by yielding time back to the event loop between batches.
final Duration batchInterval;