LoadController class

Controls a load process.

Constructors

LoadController([String? id])
LoadController.function(LoaderFunction? loader, [String? id])

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
Global ID of this loader.
getter/setter pair
isLoaded → bool
Returns true if is loaded.
no setter
isNotLoaded → bool
Returns false if is not loaded.
no setter
loader ↔ LoaderFunction?
The actual loading function that is handled by this LoadController.
getter/setter pair
loadSuccessful → bool?
Returns true if load was successful.
no setter
onLoad → EventStream<LoadController>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

load([LoaderFunction? actualLoader]) → Future<bool>
Does the load process.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited