MapProperties class

A Map of properties.

Inheritance

Properties

entries → Iterable<MapEntry<String, dynamic>>
The map entries of this Map.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty → bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys → Iterable<String>
The keys of this Map.
no setterinherited
length → int
The number of key/value pairs in the map.
no setterinherited
mainMap → Map<String, dynamic>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → Iterable
The values of this Map.
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry<String, dynamic>> newEntries) → void
Adds all key/value pairs of newEntries to this map.
inherited
cast<RK, RV>() → Map<RK, RV>
Provides a view of this map as having RK keys and RV instances, if necessary.
inherited
clear() → void
Removes all entries from the map.
inherited
containsKey(Object? key) → bool
Whether this map contains the given key.
inherited
containsValue(Object? value) → bool
Whether this map contains the given value.
inherited
findProperty<T>(List<String> keys, [T? def]) → T?
Finds a property with keys.
findPropertyAs<T>(List<String> keys, T? mapper(Object? v), [T? def]) → T?
Finds a property with keys.
findPropertyAsBool(List<String> keys, [bool? def]) → bool?
Finds a property with keys. Returns the value as bool.
findPropertyAsBoolList(List<String> keys, [List<bool>? def]) → List<bool>?
Finds a property with keys as List<bool>.
findPropertyAsDateTime(List<String> keys, [DateTime? def]) → DateTime?
Finds a property with keys. Returns the value as DateTime.
findPropertyAsDateTimeList(List<String> keys, [List<DateTime>? def]) → List<DateTime>?
Finds a property with keys as List<DateTime>.
findPropertyAsDouble(List<String> keys, [double? def]) → double?
Finds a property with keys. Returns the value as double.
findPropertyAsDoubleList(List<String> keys, [List<double>? def]) → List<double>?
Finds a property with keys as List<int>.
findPropertyAsInt(List<String> keys, [int? def]) → int?
Finds a property with keys. Returns the value as int.
findPropertyAsIntList(List<String> keys, [List<int>? def]) → List<int>?
Finds a property with keys as List<int>.
findPropertyAsNum(List<String> keys, [num? def]) → num?
Finds a property with keys. Returns the value as num.
findPropertyAsNumList(List<String> keys, [List<num>? def]) → List<num>?
Finds a property with keys as List<num>.
findPropertyAsString(List<String> keys, [String? def]) → String?
Finds a property with keys. Returns the value as String.
findPropertyAsStringList(List<String> keys, [List<String>? def]) → List<String>?
Finds a property with keys as List<String>.
findPropertyAsStringMap(List<String> keys, [Map<String, String>? def]) → Map<String, String>?
Finds a property with keys as List<Map>.
findPropertyAsStringTrim(List<String> keys, [String? def]) → String?
Finds a property with keys. Returns the value trimmed.
findPropertyAsStringTrimLC(List<String> keys, [String? def]) → String?
Finds a property with keys. Returns the value in lower case and trimmed.
findPropertyAsStringTrimUC(List<String> keys, [String? def]) → String?
Finds a property with keys. Returns the value in upper case and trimmed.
forEach(void f(String key, dynamic value)) → void
Applies action to each key/value pair of the map.
inherited
getProperty<T>(String key, [T? def]) → T?
Gets a property with key.
getPropertyAs<T>(String key, T? mapper(Object? v), [T? def]) → T?
Gets a property with key.
getPropertyAsBool(String key, [bool? def]) → bool?
Gets a property with key. Returns the value as bool.
getPropertyAsBoolList(String key, [List<bool>? def]) → List<bool>?
Gets a property with key as List<bool>.
getPropertyAsDateTime(String key, [DateTime? def]) → DateTime?
Gets a property with key. Returns the value as DateTime.
getPropertyAsDateTimeList(String key, [List<DateTime>? def]) → List<DateTime>?
Gets a property with key as List<DateTime>.
getPropertyAsDouble(String key, [double? def]) → double?
Gets a property with key. Returns the value as double.
getPropertyAsDoubleList(String key, [List<double>? def]) → List<double>?
Gets a property with key as List<double>.
getPropertyAsInt(String key, [int? def]) → int?
Gets a property with key. Returns the value as int.
getPropertyAsIntList(String key, [List<int>? def]) → List<int>?
Gets a property with key as List<int>.
getPropertyAsNum(String key, [num? def]) → num?
Gets a property with key. Returns the value as num.
getPropertyAsNumList(String key, [List<num>? def]) → List<num>?
Gets a property with key as List<num>.
getPropertyAsString(String key, [String? def]) → String?
Gets a property with key. Returns the value as String.
getPropertyAsStringList(String key, [List<String>? def]) → List<String>?
Gets a property with key as List<String>.
getPropertyAsStringMap(String key, [Map<String, String>? def]) → Map<String, String>?
Gets a property with key as List<Map>.
getPropertyAsStringTrim(String key, [String? def]) → String?
Gets a property with key. Returns the value trimmed.
getPropertyAsStringTrimLC(String key, [String? def]) → String?
Gets a property with key. Returns the value in lower case and trimmed.
getPropertyAsStringTrimUC(String key, [String? def]) → String?
Gets a property with key. Returns the value in upper case and trimmed.
map<K2, V2>(MapEntry<K2, V2> f(String key, dynamic value)) → Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String key, Object? value) → dynamic
put property value to key.
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → dynamic
Removes key and its associated value, if present, from the map.
inherited
removeWhere(bool predicate(String key, dynamic value)) → void
Removes all entries of this map that satisfy the given test.
inherited
toProperties() → Map<String, dynamic>
Returns this as a Map<String,dynamic>.
toString() → String
A string representation of this object.
override
toStringProperties() → Map<String, String>
Returns this as a Map<String,String>.
update(String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
Updates the value for the provided key.
inherited
updateAll(dynamic update(String key, dynamic value)) → void
Updates all values.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](Object? key) → dynamic
The value for the given key, or null if key is not in the map.
inherited
operator []=(String key, dynamic value) → void
Associates the key with the given value.
inherited

Static Methods

parseStringProperties(Map<String, String>? stringProperties) → Map<String, dynamic>
Parse stringProperties to properties values.
parseValue(Object? value) → Object?
Parses value to a valid property value.
toStringValue(Object? value, [String? def]) → String?
Returns value as a String.