Parameters2<A, B> class

Inheritance

Constructors

Parameters2(A a, B b)

Properties

a → A
finalinherited
b → B
final
computeHashCode → int
no setteroverride
computeHashCode2 → int
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → Parameters2<A?, B?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override