Parameters4<A, B, C, D> class

Inheritance

Constructors

Parameters4(A a, B b, C c, D d)

Properties

a → A
finalinherited
b → B
finalinherited
c → C
finalinherited
computeHashCode → int
no setteroverride
computeHashCode2 → int
no setterinherited
computeHashCode3 → int
no setterinherited
computeHashCode4 → int
no setter
d → D
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → Parameters4<A?, B?, C?, D?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override