QueryStringCredential class

A Credential that injects fields in the Query parameters.

Inheritance

Constructors

QueryStringCredential(Map<String, String> fields)

Properties

fields → Map<String, String>
The Credential tokes. Usually: {'access_token': 'the_toke_string'}s
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Returns queryString.
no setteroverride
usesAuthorizationHeader → bool
Returns false.
no setteroverride

Methods

buildAuthorizationHeaderLine() → String?
Builds the header Authorization.
inherited
buildBody(HttpRequestBody body) → HttpRequestBody?
Builds the HttpRequest body. Used by credentials that injects tokens/credentials in the body.
inherited
buildURL(String url) → String
Builds the HttpRequest URL.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited