RegExpDialect class

Represents a dialect. Compiles it on construction.

Constructors

RegExpDialect(Map<String, String> dialect, {bool multiLine = false, bool caseSensitive = true, bool throwCompilationErrors = true})

Properties

caseSensitive → bool
final
errorWords → List<String>
no setter
hasErrors → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
multiLine → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
words → List<String>
no setter

Methods

getPattern(String pattern) → RegExp
Returns a compiled RegExp pattern, using $words in dialect.
getWordErrorMessage(String word) → String?
getWordErrorPattern(String word) → String?
getWordPattern(String? word) → RegExp?
Returns RegExp pattern for word. Will cache RegExp instances.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withParameters({bool? multiLine = false, bool? caseSensitive = true, bool throwCompilationErrors = true}) → RegExpDialect
Returns a copy of this instance with parameters multiLine and caseSensitive. If this instance already have the same parameters returns this instance.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(Object? dialect, {bool multiLine = false, bool caseSensitive = true, bool throwCompilationErrors = true}) → RegExpDialect?