ResourceContentCache class

A cache for ResourceContent.

Constructors

ResourceContentCache()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setter

Methods

clear() → void
Clears the cache.
contains(Object? resource) → bool
get(Object? resource) → ResourceContent?
Returns a ResourceContent using resource as key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Object? resource) → ResourceContent?
Remove a ResourceContent associated with resource. See get for resource description.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited