SimpleFinalizerWrapper<V extends Object> class

Simple concrete implementation of FinalizerValueWrapper.

Holds a strong reference to value to be delivered on finalization.

Inheritance

Constructors

SimpleFinalizerWrapper(V value)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → V
The wrapped value associated with the finalizer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited