createWrapper abstract method
W
createWrapper(
- K key,
- V value
Creates a wrapper for the given key and value.
Implementations typically store the wrapper in an internal key → wrapper structure before returning it.
Implementation
W createWrapper(K key, V value);