getWrapper abstract method
W?
getWrapper(
- K key
Returns the wrapper currently associated with key, or null
if no association exists.
Implementation
W? getWrapper(K key);
Returns the wrapper currently associated with key, or null
if no association exists.
W? getWrapper(K key);