WithHttpStatus mixin

Implements an HttpStatus and delegates to httpStatus.

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpStatus → HttpStatus
no setter
isError → bool
Returns true if status represents any kind of error.
no setteroverride
isNotOK → bool
Returns true if ![isOK]
no setteroverride
isOK → bool
Returns true if is a successful status.
no setteroverride
isStatusAccessError → bool
Returns true if is a Access Error status: 405..418 OR IN 400, 403, 431, 451.
no setteroverride
isStatusError → bool
Returns true if any error happens: isStatusNetworkError || isStatusServerError || isStatusAccessError
no setteroverride
isStatusForbidden → bool
Returns true if is 403 status (Forbidden).
no setteroverride
isStatusNetworkError → bool
Returns true if any network error happens.
no setteroverride
isStatusNotFound → bool
Returns true if is 404 status (Not Found).
no setteroverride
isStatusRedirect → bool
Returns true if is 300-303 or 307-308 status (Redirect).
no setteroverride
isStatusServerError → bool
Returns true if is a server error status: from range 500 to 599.
no setteroverride
isStatusSuccessful → bool
Returns true if is a successful status: from range 200 to 299.
no setteroverride
isStatusUnauthenticated → bool
Returns true if is 401 status (Unauthenticated).
no setteroverride
requestedURL → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int
no setteroverride
url → String
no setteroverride

Methods

isStatus(int status) → bool
Returns true if this status is equals parameter status.
override
isStatusInList(List<int> statusList) → bool
Returns true if this status is in statusList.
override
isStatusInRange(int statusInit, int statusEnd) → bool
Returns true if this status is in range of parameters statusInit and statusEnd.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited