CSS class

CSS entries.

Constructors

CSS([Object? css])
factory

Properties

background ↔ CSSEntry<CSSBackground>?
getter/setter pair
backgroundColor ↔ CSSEntry<CSSColor>?
getter/setter pair
border ↔ CSSEntry<CSSBorder>?
getter/setter pair
color ↔ CSSEntry<CSSColor>?
getter/setter pair
display ↔ CSSEntry<CSSGeneric>?
getter/setter pair
entries → List<CSSEntry<CSSValue>>
no setter
entriesAsString → List<String>
no setter
hashCode → int
The hash code for this object.
no setteroverride
height ↔ CSSEntry<CSSLength>?
getter/setter pair
isEmpty → bool
no setter
isNoEmpty → bool
no setter
length → int
no setter
opacity ↔ CSSEntry<CSSNumber>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → String
no setter
width ↔ CSSEntry<CSSLength>?
getter/setter pair

Methods

containsEntry<V extends CSSValue>(CSSEntry<V> entry) → bool
copy() → CSS
get<V extends CSSValue>(String name) → V?
getAsString<V extends CSSValue>(String name) → String?
getEntry<V extends CSSValue>(String name) → CSSEntry<V>?
getPossibleEntries() → List<CSSEntry<CSSValue>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String name, Object? value) → void
putAll(List<CSSEntry<CSSValue>> entries) → void
putAllIfAbsent(List<CSSEntry<CSSValue>> entries) → void
putAllProperties(Map<String, dynamic> properties) → void
putEntry<V extends CSSValue>(CSSEntry<V> entry) → void
putEntryIfAbsent<V extends CSSValue>(CSSEntry<V> entry) → void
putIfAbsent(String name, Object? value) → void
removeEntry<V extends CSSValue>(String name) → CSSEntry<V>?
toString([DOMContext? domContext]) → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override
operator [](String key) → CSSValue?
operator []=(String key, dynamic value) → void

Static Properties

entriesDelimiter → RegExp
final

Static Methods

parse(String? css) → CSS?
parseList(List<String> entries) → CSS?