CSSAnimationConfig class abstract

Constructors

CSSAnimationConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotValid → bool
Returns false if this configuration is NOT valid;
no setter
isValid → bool
Returns true if this configuration is valid;
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
play({Duration? initialDelay, AnimationCallback? callback}) → Future<void>?
Plays CSS animation.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited