CSSAnimationConfigGroup class

CSS animation configuration for a group of CSSAnimationConfig.

Inheritance

Properties

configs → List<CSSAnimationConfig>
Group of CSSAnimationConfig.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isNotValid → bool
Returns false if this configuration is NOT valid;
no setterinherited
isValid → bool
Returns true if this configuration is valid;
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
play({Duration? initialDelay, AnimationCallback? callback}) → Future<void>
Plays CSS animation.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited