CSSBackground class

A CSS background value.

Inheritance

Properties

calc → CSSCalc?
no setterinherited
color ↔ CSSColor?
getter/setter pair
firstImage → CSSBackgroundImage?
no setter
function → CSSFunction?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasImages → bool
no setter
images → List<CSSBackgroundImage>
no setter
imagesLength → int
no setter
isCalc → bool
no setterinherited
isFunction → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getImage(int idx) → CSSBackgroundImage?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext<Object>? domContext]) → String
A string representation of this object.
override
toStringCalc([DOMContext<Object>? domContext]) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

patternColor → RegExp
final
patternColorImage → RegExp
final
patternImage → RegExp
final
patternImageCapture → RegExp
final
patternImages → RegExp
final

Static Methods

from(Object? value) → CSSBackground?
override
parse(String value) → CSSBackground?