CSSBackgroundGradient class

A CSS background gradient value.

Constructors

CSSBackgroundGradient(String? type, List<String> parameters)

Properties

hashCode → int
The hash code for this object.
no setterinherited
parameters → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited