CSSBackgroundImage class

Properties

attachment → CSSBackgroundAttachment?
final
clip → CSSBackgroundBox?
final
gradient → CSSBackgroundGradient?
final
hashCode → int
The hash code for this object.
no setterinherited
origin → CSSBackgroundBox?
final
position → String?
final
repeat → CSSBackgroundRepeat?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → String?
final
url → CSSURL?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext? domContext]) → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

patternGradient → RegExp
final
patternPropsCapture → RegExp
final
patternURL → RegExp
final

Static Methods

from(Object? value) → CSSBackgroundImage?
parse(String? value) → CSSBackgroundImage?