CSSBorder class

A CSS border value.

Inheritance

Constructors

CSSBorder([CSSLength? size, CSSBorderStyle? style, CSSColor? color])

Properties

calc → CSSCalc?
no setterinherited
color ↔ CSSColor?
getter/setter pair
function → CSSFunction?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isCalc → bool
no setterinherited
isFunction → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ CSSLength?
getter/setter pair
style ↔ CSSBorderStyle
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext? domContext]) → String
A string representation of this object.
override
toStringCalc([DOMContext? domContext]) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

pattern → RegExp
final

Static Methods

from(Object? value) → CSSBorder?
override
parse(String? value) → CSSBorder?