CSSCalc class

A CSS calc(...) value.

Inheritance

Properties

a → String
final
b → String?
final
calc → CSSCalc?
no setterinherited
function → CSSFunction?
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
hasOperation → bool
no setter
isCalc → bool
no setterinherited
isFunction → bool
no setterinherited
operation → CalcOperation?
final
operationSymbol → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compute([DOMContext? domContext]) → CSSValue?
override
computeUnit([DOMContext? domContext]) → CSSUnit?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext? domContext]) → String
A string representation of this object.
override
toStringCalc([DOMContext? domContext]) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

pattern → RegExp
final
patternExpressionOperation → RegExp
final

Static Methods

from(Object? calc) → CSSCalc?
override
parse(String? calc) → CSSCalc?
override