CSSColor class abstract

Base class for CSS colors.

Inheritance

Constructors

CSSColor()

Properties

args → String
no setter
argsNoAlpha → String
no setter
asCSSColorHEX → CSSColorHEX
no setter
asCSSColorRGB → CSSColorRGB
no setter
asCSSColorRGBA → CSSColorRGBA
no setter
calc → CSSCalc?
no setterinherited
function → CSSFunction?
no setterinherited
hasAlpha → bool
no setter
hashCode → int
The hash code for this object.
no setteroverride
inverse → CSSColor
no setter
isCalc → bool
no setterinherited
isFunction → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext? domContext]) → String
A string representation of this object.
inherited
toStringCalc([DOMContext? domContext]) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

from(Object? color) → CSSColor?
override
parse(String? color) → CSSColor?