CSSColorHEX class

A CSSColor in HEX (no alpha).

Inheritance

Constructors

CSSColorHEX(String hexColor)
factory
CSSColorHEX.fromRGB(int red, int green, int blue)
factory

Properties

args → String
no setterinherited
argsNoAlpha → String
no setterinherited
asCSSColorHEX → CSSColorHEX
no setteroverride
asCSSColorRGB → CSSColorRGB
no setteroverride
asCSSColorRGBA → CSSColorRGBA
no setterinherited
blue ↔ int
getter/setter pairinherited
calc → CSSCalc?
no setterinherited
function → CSSFunction?
no setterinherited
green ↔ int
getter/setter pairinherited
hasAlpha → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inverse → CSSColorHEX
no setteroverride
isCalc → bool
no setterinherited
isFunction → bool
no setterinherited
red ↔ int
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext? domContext]) → String
A string representation of this object.
override
toStringCalc([DOMContext? domContext]) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

patternHex → RegExp
final

Static Methods

from(Object? color) → CSSColorHEX?
override
parse(String color) → CSSColorHEX?
override