CSSColorName class

A CSSColor by name.

Inheritance

Constructors

CSSColorName(String hexColor)
factory

Properties

alpha ↔ double?
getter/setter pair
args → String
no setterinherited
argsNoAlpha → String
no setterinherited
asCSSColorHEX → CSSColorHEX
no setterinherited
asCSSColorRGB → CSSColorRGB
no setterinherited
asCSSColorRGBA → CSSColorRGBA
no setteroverride
blue ↔ int
getter/setter pairinherited
calc → CSSCalc?
no setterinherited
function → CSSFunction?
no setterinherited
green ↔ int
getter/setter pairinherited
hasAlpha → bool
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inverse → CSSColorRGB
no setterinherited
isCalc → bool
no setterinherited
isFunction → bool
no setterinherited
name → String
final
red ↔ int
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext? domContext]) → String
A string representation of this object.
override
toStringCalc([DOMContext? domContext]) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

patternWord → RegExp
final

Static Methods

from(Object? color) → CSSColorName?
override
parse(String color) → CSSColorName?
override

Constants

colorsNames → const Map<String, String>