CSSColorRGBA class

Inheritance

Constructors

CSSColorRGBA(int? red, int? green, int? blue, double? alpha)

Properties

alpha ↔ double
getter/setter pair
args → String
no setteroverride
argsNoAlpha → String
no setterinherited
argsWithoutAlpha → String
no setter
asCSSColorHEX → CSSColorHEX
no setterinherited
asCSSColorRGB → CSSColorRGB
no setterinherited
asCSSColorRGBA → CSSColorRGBA
no setteroverride
blue ↔ int
getter/setter pairinherited
calc → CSSCalc?
no setterinherited
function → CSSFunction?
no setterinherited
green ↔ int
getter/setter pairinherited
hasAlpha → bool
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inverse → CSSColorRGB
no setterinherited
isCalc → bool
no setterinherited
isFunction → bool
no setterinherited
red ↔ int
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext? domContext]) → String
A string representation of this object.
override
toStringCalc([DOMContext? domContext]) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(Object? color) → CSSColorRGBA?
override
parse(String color) → CSSColorRGBA?
override