CSSFunction class abstract

Base class for a CSSValue that is a CSS function.

Inheritance

Constructors

CSSFunction()

Properties

calc → CSSCalc?
no setterinherited
function → CSSFunction?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isCalc → bool
no setterinherited
isFunction → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compute([DOMContext? domContext]) → CSSValue?
computeUnit([DOMContext? domContext]) → CSSUnit?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext? domContext]) → String
A string representation of this object.
inherited
toStringCalc([DOMContext? domContext]) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

computeValue(CSSValue cssValue, [DOMContext? domContext]) → CSSValue?
from(Object? o) → CSSFunction?
override
parse(String? s) → CSSFunction?