CSSGeneric class

A generic CSS value.

Inheritance

Constructors

CSSGeneric(String value)

Properties

calc → CSSCalc?
no setterinherited
function → CSSFunction?
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
isCalc → bool
no setterinherited
isFunction → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext? domContext]) → String
A string representation of this object.
override
toStringCalc([DOMContext? domContext]) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

from(Object? value) → CSSGeneric?
override
parse(String? value) → CSSGeneric?