CSSLength class

A CSS value that represents a length with a unit.

Inheritance

Constructors

CSSLength(num value, [CSSUnit unit = CSSUnit.px])
CSSLength.fromCalc(CSSCalc calc)
CSSLength.fromFunction(CSSFunction f)

Properties

calc → CSSCalc?
no setterinherited
function → CSSFunction?
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
isCalc → bool
no setterinherited
isFunction → bool
no setterinherited
isPercent → bool
Returns true if unit is of type %.
no setter
isPx → bool
Returns true if unit is of type px.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit ↔ CSSUnit
getter/setter pair
value ↔ num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext? domContext]) → String
A string representation of this object.
override
toStringCalc([DOMContext? domContext]) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

pattern → RegExp
final

Static Methods

from(Object? value) → CSSLength?
override
parse(String? value) → CSSLength?
resolveValue(DOMContext? domContext, num value, CSSUnit unit, {bool originalValueAsComment = true}) → CSSLength
resolveValueAsString(DOMContext? domContext, num value, CSSUnit unit, {bool originalValueAsComment = true}) → String
valueToString(num value, CSSUnit unit) → String