CSSThemeSet class

A Theme set, with multiples themes.

Constructors

CSSThemeSet(String cssPrefix, List<Map<String, CSSValueBase>> _themes, [int defaultThemeIndex = 0])

Properties

cssPrefix → String
final
defaultThemeIndex → int
final
hashCode → int
The hash code for this object.
no setterinherited
loadedTheme → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ensureThemeLoaded() → void
Ensures that the defaultThemeIndex is loaded into DOM.
getCSSTheme(int themeIndex) → Map<String, CSSValueBase>?
loadCSSTheme(Map<String, CSSValueBase>? css) → void
Loads css into DOM.
loadTheme(int themeIndex) → int
Loads theme at themeIndex.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited