CSSURL class

A CSS url(...) value.

Inheritance

Constructors

CSSURL(String? url)

Properties

calc → CSSCalc?
no setterinherited
function → CSSFunction?
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
isCalc → bool
no setterinherited
isFunction → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext? domContext]) → String
A string representation of this object.
override
toStringCalc([DOMContext? domContext]) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

pattern → RegExp
final

Static Methods

from(Object? url) → CSSURL?
override
parse(String? url) → CSSURL?