CSSValue class abstract

Base class for CSSEntry values.

Properties

calc → CSSCalc?
no setter
function → CSSFunction?
no setter
hashCode → int
The hash code for this object.
no setteroverride
isCalc → bool
no setter
isFunction → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([DOMContext? domContext]) → String
A string representation of this object.
override
toStringCalc([DOMContext? domContext]) → String?

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

from(Object value, [String? name]) → CSSValue?
parseByName(Object value, String name) → CSSValue?