DOMActionSelect<T extends Object> class

Inheritance

Constructors

DOMActionSelect(DOMActionExecutor<T> executor, String id)

Properties

executor → DOMActionExecutor<T>
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
id → String
final
next ↔ DOMAction<T>?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

actionString() → String
override
execute(T? target, {T? self, DOMTreeMap<Object>? treeMap, DOMContext<Object>? context}) → T?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override