DOMAttribute class

Represents a DOMElement attribute entry (name and DOMAttributeValue).

Mixed-in types

Constructors

DOMAttribute(String name, DOMAttributeValue valueHandler)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasValue → bool
Returns true if has value.
no setteroverride
isBoolean → bool
no setter
isCollection → bool
no setter
isList → bool
no setter
isSet → bool
no setter
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
no setteroverride
valueAsBool → bool?
Returns value as bool.
no setterinherited
valueAsDouble → double?
Returns value as double.
no setterinherited
valueAsInt → int?
Returns value as bool.
no setterinherited
valueAsNum → num?
Returns value as num.
no setterinherited
valueHandler → DOMAttributeValue
final
valueLength → int
no setter
values → List<String>?
no setter

Methods

appendValue(Object? value) → void
buildHTML({DOMContext<Object>? domContext, DSXResolution dsxResolution = DSXResolution.skipDSX}) → String
containsValue(Object? value) → bool
getValue([DOMContext<Object>? domContext, DOMTreeMap<Object>? treeMap]) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBoolean(Object? value) → void
setValue(Object? value) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

append(String s, String delimiter, DOMAttribute? attribute, {DOMContext<Object>? domContext, DSXResolution dsxResolution = DSXResolution.skipDSX}) → String
appendTo(StringBuffer s, String delimiter, DOMAttribute? attribute, {DOMContext<Object>? domContext, DSXResolution dsxResolution = DSXResolution.skipDSX}) → StringBuffer
from(String? name, Object? value) → DOMAttribute?
getAttributeDelimiter(String name) → String?
getAttributeDelimiterPattern(String name) → RegExp?
isBooleanAttribute(String attrName) → bool
normalizeName(String? name) → String?