DOMAttributeValue class abstract

Base class for DOMAttribute value.

Constructors

DOMAttributeValue()

Properties

asAttributeValue → String?
no setter
asAttributeValues → List<String>?
no setter
hasAttributeValue → bool
Returns true if has a value.
no setter
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

containsAttributeValue(Object? value) → bool
Parses value and returns true if this instance contains it.
equalsAttributeValue(Object? value) → bool
Parses value and returns true if is equals to this instance value.
getAttributeValue([DOMContext<Object>? domContext, DOMTreeMap<Object>? treeMap]) → String?
Returns the attribute value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttributeValue(Object? value) → void
Parses value and sets this instances value.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited