DOMAttributeValueCSS class

A DOMAttributeValue of type CSS.

Inheritance

Constructors

DOMAttributeValueCSS(Object? values)

Properties

asAttributeValue → String?
no setteroverride
asAttributeValues → List<String>
no setteroverride
css → CSS
no setter
hasAttributeValue → bool
Returns true if has a value.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendAttributeValue(Object? value) → void
override
containsAttributeValue(Object? value) → bool
Parses value and returns true if this instance contains it.
override
containsAttributeValueEntry(Object? value) → bool
override
equalsAttributeValue(Object? value) → bool
Parses value and returns true if is equals to this instance value.
override
getAttributeValue([DOMContext<Object>? domContext, DOMTreeMap<Object>? treeMap]) → String?
Returns the attribute value.
override
getAttributeValueEntry(Object? name) → String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAttributeValueAllEntries(List entries) → void
inherited
removeAttributeValueEntry(Object? name) → String?
override
setAttributeValue(Object? value) → void
Parses value and sets this instances value.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited