DOMAttributeValueCollection class abstract

Base DOMAttributeValue class for collections.

Inheritance

Properties

asAttributeValue → String?
no setterinherited
asAttributeValues → List<String>?
no setterinherited
hasAttributeValue → bool
Returns true if has a value.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendAttributeValue(Object? value) → void
containsAttributeValue(Object? value) → bool
Parses value and returns true if this instance contains it.
inherited
containsAttributeValueEntry(Object? value) → bool
equalsAttributeValue(Object? value) → bool
Parses value and returns true if is equals to this instance value.
inherited
getAttributeValue([DOMContext? domContext, DOMTreeMap? treeMap]) → String?
Returns the attribute value.
inherited
getAttributeValueEntry(Object? name) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAttributeValueAllEntries(List entries) → void
removeAttributeValueEntry(Object? name) → String?
setAttributeValue(Object? value) → void
Parses value and sets this instances value.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited