DOMAttributeValueString class

Inheritance

Constructors

DOMAttributeValueString(Object? value)

Properties

asAttributeValue → String?
no setteroverride
asAttributeValues → List<String>?
no setteroverride
hasAttributeValue → bool
Returns true if has a value.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

containsAttributeValue(Object? value) → bool
Parses value and returns true if this instance contains it.
override
equalsAttributeValue(Object? value) → bool
Parses value and returns true if is equals to this instance value.
override
getAttributeValue([DOMContext? domContext, DOMTreeMap? treeMap]) → String?
Returns the attribute value.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttributeValue(Object? value) → void
Parses value and sets this instances value.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited