DOMEvent<T extends Object> class

Base class for DOMElement events.

Constructors

DOMEvent(DOMTreeMap<T> treeMap, Object? event, Object? eventTarget, DOMNode? target)

Properties

domGenerator → DOMGenerator<T>
no setter
event → Object?
final
eventTarget → Object?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → DOMNode?
final
treeMap → DOMTreeMap<T>
final

Methods

cancel({bool stopImmediatePropagation = false}) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited