DOMMouseEvent<T> class

Represents a mouse event.

Inheritance

Constructors

DOMMouseEvent(DOMTreeMap<T> treeMap, Object? event, Object? eventTarget, DOMNode? target, Point<num> client, Point<num> offset, Point<num> page, Point<num> screen, int button, int? buttons, bool altKey, bool ctrlKey, bool shiftKey, bool metaKey)
DOMMouseEvent.synthetic({DOMTreeMap<T>? treeMap, Object? event, Object? eventTarget, DOMNode? target, Point<num>? client, Point<num>? offset, Point<num>? page, Point<num>? screen, int button = 0, int? buttons, bool altKey = false, bool ctrlKey = false, bool shiftKey = false, bool metaKey = false})
Creates an artificial event. Useful to generated events programmatically.
factory

Properties

altKey → bool
final
button → int
final
buttons → int?
final
client → Point<num>
final
ctrlKey → bool
final
domGenerator → DOMGenerator<T>
no setterinherited
event → Object?
finalinherited
eventTarget → Object?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
metaKey → bool
final
offset → Point<num>
final
page → Point<num>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screen → Point<num>
final
shiftKey → bool
final
target → DOMNode?
finalinherited
treeMap → DOMTreeMap<T>
finalinherited

Methods

cancel({bool stopImmediatePropagation = false}) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited