DOMNodeRuntimeDummy<T extends Object> class

Inheritance

Constructors

DOMNodeRuntimeDummy(DOMTreeMap<T>? treeMap, DOMNode domNode, T? node)

Properties

children → List<T>
Returns the List of children nodes.
no setteroverride
classes → List<String>
Returns the classes of this node.
no setteroverride
domGenerator → DOMGenerator<T>
The DOMGenerator used to generate this treeMap.
no setterinherited
domNode → DOMNode?
The DOMNode of this node.
finalinherited
exists → bool
Returns true if this node and domNode exists.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasParent → bool
Returns true if this node has a parent.
no setterinherited
indexInParent → int
no setteroverride
isStringElement → bool
Returns true if this node is a String element (a Text node or DOMElement.isStringTagName).
no setteroverride
node → T?
The runtime node (generated element/node).
finalinherited
nodesLength → int
Returns the number of children nodes.
no setteroverride
parent → T?
This node parent.
no setterinherited
parentRuntime → DOMNodeRuntime<T>?
The DOMNodeRuntime of parent.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ CSS
Gets runtime style of node as CSS.
getter/setter pairinherited
tagName → String?
The tag name of this node.
no setteroverride
text ↔ String
Returns the text of this node.
getter/setter pairoverride
treeMap → DOMTreeMap<T>?
finalinherited
value ↔ String
getter/setter pairoverride

Methods

absorbNode(T? other) → bool
override
add(T child) → void
Adds child node.
override
addClass(String? className) → void
Adds a className to this node classes.
override
clear() → void
override
clearClasses() → void
Clears classes from this node classes.
override
copy() → T?
Copies this node.
override
duplicate() → T?
Duplicates this node, inserting it at parent.
inherited
getAttribute(String name) → String?
Returns the value of the attribute of name.
override
getNodeAt(int index) → T?
Returns the node at index.
override
getSiblingRuntime(T? other) → DOMNodeRuntime<T>?
inherited
getStyleEntry(String name) → CSSEntry<CSSValue>?
Gets a runtime style CSSEntry for name from node.
inherited
getStyleProperty(String name) → String?
Gets a runtime style property for name from node.
inherited
indexOf(T child) → int
Returns the index of child.
override
insertAt(int index, T? child) → void
Inserts child node at index.
override
isConsecutiveNode(T other) → bool
inherited
isInSameParent(T other) → bool
Returns true if other is in the same parent of this node.
inherited
isNextNode(T? other) → bool
inherited
isPreviousNode(T? other) → bool
inherited
mergeNode(T? other, {bool onlyConsecutive = true}) → bool
inherited
moveDown() → bool
Moves this node down in parent's children.
inherited
moveUp() → bool
Moves this node up in parent's children.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → bool
Removes this node.
inherited
removeAt(int index) → T?
Removes child node at index.
override
removeAttribute(String name) → void
Removes the attribute of name.
override
removeClass(String? className) → bool
Removes className from this node classes.
override
removeNode(T? child) → bool
Removes child node.
override
removeStyleEntries(List<String> names) → List<CSSEntry<CSSValue>>
inherited
removeStyleEntry(String name) → CSSEntry<CSSValue>?
inherited
removeStyleProperties(List<String> names) → Map<String, String>
inherited
removeStyleProperty(String name) → String?
inherited
replaceBy(List? elements, {bool remap = false}) → bool
Replaces this node with elements.
inherited
setAttribute(String name, String value) → void
Sets the value of the attribute of name.
override
setStyleProperties(Map<String, String> properties) → void
inherited
setStyleProperty(String name, String value) → String?
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String name) → String?
inherited
operator []=(String name, Object? value) → void
inherited