DOMTemplate class abstract

Constructors

DOMTemplate()

Properties

asDSX → DSX?
Returns this node as an DSX instance if isDSX returns true.
no setter
hasDSX → bool
Returns true if this node or any sub-node is a DSX entry.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isDSX → bool
Returns true if this node is a DSX entry.
no setter
isEmpty → bool
Returns true if this node is empty.
no setter
isNotEmpty → bool
Returns true if this node NOT is empty.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(DOMTemplate entry) → bool
build(Object? context, {bool asElement = true, bool resolveDSX = true, QueryElementProvider? elementProvider, IntlMessageResolver? intlMessageResolver}) → dynamic
copy({bool resolveDSX = false}) → DOMTemplate
Returns a copy if this instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

regexpTag → RegExp
final

Static Methods

from(Object? value) → DOMTemplate?
objectToString(dynamic o) → String
parse(String s) → DOMTemplateNode
Parses s and returns a DOMTemplateNode.
possiblyATemplate(String s) → bool
Returns true if s can be a template code, has {{ and }}.
tryParse(String? s) → DOMTemplateNode?
Tries to parse s.