DOMTemplateBlockCondition class abstract

Inheritance

Constructors

DOMTemplateBlockCondition(DOMTemplateVariable? variable, [DOMTemplateNode? content])

Properties

asDSX → DSX<Object>?
Returns this node as an DSX instance if isDSX returns true.
no setterinherited
elseCondition ↔ DOMTemplateBlockCondition?
getter/setter pair
hasDSX → bool
Returns true if this node or any sub-node is a DSX entry.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasOnlyContent → bool
no setterinherited
isDSX → bool
Returns true if this node is a DSX entry.
no setterinherited
isEmpty → bool
Returns true if this node is empty.
no setterinherited
isNotEmpty → bool
Returns true if this node NOT is empty.
no setterinherited
nodes ↔ List<DOMTemplate>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variable → DOMTemplateVariable?
finalinherited

Methods

add(DOMTemplate? entry) → bool
inherited
addAll(List<DOMTemplate> entries) → bool
inherited
build(Object? context, {bool asElement = true, DSXResolution dsxResolution = DSXResolution.resolveDSX, QueryElementProvider? elementProvider, IntlMessageResolver? intlMessageResolver}) → dynamic
override
buildAsString(Object? context, {DSXResolution dsxResolution = DSXResolution.resolveDSX, QueryElementProvider? elementProvider, IntlMessageResolver? intlMessageResolver}) → String
inherited
buildContent(Object? context, {bool asElement = true, DSXResolution dsxResolution = DSXResolution.resolveDSX, QueryElementProvider? elementProvider}) → dynamic
clear() → void
inherited
copy({DSXResolution dsxResolution = DSXResolution.skipDSX}) → DOMTemplate
Returns a copy if this instance.
inherited
copyNodes({DSXResolution dsxResolution = DSXResolution.skipDSX}) → List<DOMTemplate>
inherited
evaluate(Object? context, {DSXResolution dsxResolution = DSXResolution.resolveDSX}) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited