DOMTemplateBlockIfCmp class

Inheritance

Constructors

DOMTemplateBlockIfCmp(bool elseIf, DOMTemplateVariable? variable, Object? cmp, Object? value, [DOMTemplateNode? content])

Properties

asDSX → DSX?
Returns this node as an DSX instance if isDSX returns true.
no setterinherited
cmp → DOMTemplateCmp?
final
elseCondition ↔ DOMTemplateBlockCondition?
getter/setter pairinherited
elseIf → bool
final
hasDSX → bool
Returns true if this node or any sub-node is a DSX entry.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasOnlyContent → bool
no setterinherited
isDSX → bool
Returns true if this node is a DSX entry.
no setterinherited
isEmpty → bool
Returns true if this node is empty.
no setterinherited
isNotEmpty → bool
Returns true if this node NOT is empty.
no setterinherited
nodes ↔ List<DOMTemplate>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Object?
final
variable → DOMTemplateVariable?
finalinherited

Methods

add(DOMTemplate? entry) → bool
inherited
addAll(List<DOMTemplate> entries) → bool
inherited
build(Object? context, {bool asElement = true, bool resolveDSX = true, QueryElementProvider? elementProvider, IntlMessageResolver? intlMessageResolver}) → dynamic
inherited
buildAsString(Object? context, {bool resolveDSX = true, QueryElementProvider? elementProvider, IntlMessageResolver? intlMessageResolver}) → String
inherited
buildContent(Object? context, {bool asElement = true, bool resolveDSX = true, QueryElementProvider? elementProvider}) → dynamic
inherited
clear() → void
inherited
copy({bool resolveDSX = false}) → DOMTemplateBlockIfCmp
Returns a copy if this instance.
override
copyNodes({bool resolveDSX = false}) → List<DOMTemplate>
inherited
evaluate(Object? context) → bool
override
getValueAsString(Object? context) → String?
matchesEq(Object? context) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toStringValue() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited