isMappedElement method
Returns true if element is mapped by this instance.
Implementation
bool isMappedElement(T? element) {
if (element == null) return false;
return _elementToDOMNodeMap?.containsKey(element) ?? false;
}
Returns true if element is mapped by this instance.
bool isMappedElement(T? element) {
if (element == null) return false;
return _elementToDOMNodeMap?.containsKey(element) ?? false;
}