DSX<T> class

A DSX object.

Can be a Function/lambda that will be inserted into DOM definitions passed to $dsx.

Constructors

DSX(Object objSource, T obj, {List? parameters})
Creates a DSX object that makes a reference to object with parameters.
factory
DSX.varArgs(Object objSource, T obj, [dynamic a1, dynamic a2, dynamic a3, dynamic a4, dynamic a5, dynamic a6, dynamic a7, dynamic a8, dynamic a9, dynamic a10])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
final
isFunction → bool
no setter
isFuture → bool
no setter
keyID → int
no setter
object → Object?
no setter
objectSource → Object?
no setter
parameters → List?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Returns the type of this DSX object as String.
no setter

Methods

call() → dynamic
check() → DSX<T>
Check the referenced object that this DSX instance still exists.
createResolver() → DSXResolver
equalsParameters(List? parameters) → bool
Returns true if parameters are equals to this.parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
This DSX object referend mark as String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

markRegExp → RegExp
final

Static Methods

isDSXMark(String s) → bool
Returns true if s is a DSX reference mark. Example: __DSX__function_3
objectFromDSX(DSX dsx) → Object?
objectSourceFromDSX(DSX dsx) → Object?
parseDSXMarkID(String s) → int?
Parses s to a DSX reference mark ID.
resolveDSX(dynamic o) → DSX?
Resolve o to a DSX object.
resolveObject(dynamic o) → Object?
Resolve o to the related DSX.object of a DSX instance.