DSXObjectType enum

Inheritance
Available extensions

Values

function → const DSXObjectType
const DSXObjectType('function', 'function_')
future → const DSXObjectType
const DSXObjectType('future', 'future_')
generic → const DSXObjectType
const DSXObjectType('', '')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
placeholder → String
final
placeholderPrefix → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

forObject(Object? obj) → dynamic

Constants

values → const List<DSXObjectType>
A constant List of the values in this enum, in order of their declaration.