DSXResolution class

Constructors

DSXResolution.lifecycleManager(DSXLifecycleManager? lifecycleManager, {bool resolve = true})
DSXResolution.resolve(bool resolve)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lifecycleManager → DSXLifecycleManager?
final
resolve → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? resolve, DSXLifecycleManager? lifecycleManager, bool nullLifecycleManager = false}) → DSXResolution
noLifecycleManager() → DSXResolution
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

resolveDSX → const DSXResolution
skipDSX → const DSXResolution