Device class abstract final

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

cssPrefix → String
final
isFirefox → bool
final
isIE → bool
final
isOpera → bool
final
isWebKit → bool
final
propertyPrefix → String
final
userAgent → String
no setter