ElementGeneratorFunctions<T extends Object> class

Inheritance

Constructors

ElementGeneratorFunctions(String tag, ElementGeneratorFunction<T> generator, {ElementRevertFunction<T>? reverter, ElementGeneratedMatchingFunction<Object>? elementMatcher, bool hasChildrenElements = true, bool usesContentHolder = true})

Properties

elementMatcher → ElementGeneratedMatchingFunction<Object>?
final
generator → ElementGeneratorFunction<T>
final
hasChildrenElements → bool
If true indicated that this generated element has children nodes.
final
hashCode → int
The hash code for this object.
no setterinherited
reverter → ElementRevertFunction<T>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String
final
usesContentHolder → bool
If true will use a div as a content holder, with already generated content to be passed to generate call.
final

Methods

generate(DOMGenerator<T> domGenerator, DOMTreeMap<T> treeMap, String? tag, DOMElement? domParent, T? parent, DOMNode domNode, Map<String, DOMAttribute> attributes, T? contentHolder, List<DOMNode>? contentNodes, DOMContext<T>? context) → T
override
isGeneratedElement(T element) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revert(DOMGenerator<T> domGenerator, DOMTreeMap<T>? treeMap, DOMElement? domParent, T? parent, T? node) → DOMElement
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited