FilterResult class

Filter result.

Used by ImagePerspectiveFilter.

Constructors

FilterResult(CanvasImageSource? imageSource, HTMLCanvasElement imageResult, Rectangle<num> crop)

Properties

crop → Rectangle<num>
final
hashCode → int
The hash code for this object.
no setterinherited
imageResult → HTMLCanvasElement
final
imageResultCropped → HTMLCanvasElement?
no setter
imageSource → CanvasImageSource?
final
resultHeight → int
no setter
resultWidth → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translation → Point<num>
no setter

Methods

copyWithoutSource() → FilterResult
copyWithSource(CanvasImageSource? imageSource) → FilterResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
translationScaled(double scale) → Point<num>

Operators

operator ==(Object other) → bool
The equality operator.
inherited