ImagePerspectiveFilter class

A filter that applies a perspective to an image.

Constructors

ImagePerspectiveFilter(CanvasImageSource image, int width, int height)

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → int
Image height.
final
image → CanvasImageSource
The image to filter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
Image width.
final

Methods

filter([CanvasElement? resultCanvas]) → FilterResult?
Filters the image into resultCanvas.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCorners(double x0, double y0, double x1, double y1, double x2, double y2, double x3, double y3) → void
setCornersFromDimensionRatio(double x0, double y0, double x1, double y1, double x2, double y2, double x3, double y3) → void
setCornersFromInts(int x0, int y0, int x1, int y1, int x2, int y2, int x3, int y3) → void
setCornersFromNumList(List<num> points) → void
setCornersFromPoints(Point<num> p0, Point<num> p1, Point<num> p2, Point<num> p3) → void
setCornersFromPointsList(List<Point<num>> points) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited