ImagePerspectiveFilterCache class

A cache for perspective filers.

Useful for consecutive calls to perspective on the same image.

Inheritance

Constructors

ImagePerspectiveFilterCache(CanvasImageSource image, [int? width, int? height, int? maxScaleCacheEntries, int? maxPerspectiveCacheEntries])

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → int
Height of the main image.
no setterinherited
image → CanvasImageSource
Main image for scale.
no setterinherited
maxPerspectiveCacheEntries → int?
no setter
maxScaleCacheEntries → int
Maximum number of entries in the cache.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
Width of the main image.
no setterinherited

Methods

clearCaches() → void
clearPerspectiveCache() → void
clearScaleCache() → void
Clears the cache.
inherited
getImageScaled(double scale) → CanvasImageSource?
Returns a cached image in scale.
inherited
getImageWithPerspective(List<Point<num>>? points, double scale) → FilterResult?
isImageScaledInCache(double scale) → bool
Returns true if a scale is in cache.
inherited
isImageWithPerspectiveInCache(List<Point<num>>? points, double scale) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited