ImageScaledCache class

A cache for scaled images.

Constructors

ImageScaledCache(CanvasImageSource _image, [int? width, int? height, int? maxScaleCacheEntries])

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → int
Height of the main image.
no setter
image → CanvasImageSource
Main image for scale.
no setter
maxScaleCacheEntries → int
Maximum number of entries in the cache.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
Width of the main image.
no setter

Methods

clearScaleCache() → void
Clears the cache.
getImageScaled(double scale) → CanvasImageSource?
Returns a cached image in scale.
isImageScaledInCache(double scale) → bool
Returns true if a scale is in cache.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

limitEntries(Map cache, int maxCacheEntries) → int