IterableDomElementExtension<E extends Element> extension

on

Methods

addClass(String clazz) → void

Available on Iterable<E>, provided by the IterableDomElementExtension extension

Adds a class to all elements of this Iterable of Elements.
removeClass(String clazz) → void

Available on Iterable<E>, provided by the IterableDomElementExtension extension

Removes a class from all elements of this Iterable of Elements.
whithClass(String clazz) → List<E>

Available on Iterable<E>, provided by the IterableDomElementExtension extension

Filter elements with clazz.
whithClasses(List<String> classes) → List<E>

Available on Iterable<E>, provided by the IterableDomElementExtension extension

Filter elements with all classes.
withID(String id) → List<E>

Available on Iterable<E>, provided by the IterableDomElementExtension extension

Filter elements with id.