JSImmutableListWrapper<T extends JSObject, U extends JSObject> class

A wrapper to present a JS immutable list of type T and list item type U as a List<U>.

Implemented types
Mixed-in types
Available extensions

Constructors

JSImmutableListWrapper(T original)

Properties

elementsValues → List<String?>

Available on Iterable<E>, provided by the UIIterableElementExtension extension

Returns a List of values of this Iterable of UIElements.
no setter
first ↔ U
The first element.
getter/setter pairinherited-setteroverride-getter
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<U>
A new Iterator that allows iterating the elements of this Iterable.
no setterinherited
last ↔ U
The last element.
getter/setter pairinherited-setteroverride-getter
length ↔ int
The number of objects in this list.
getter/setter pairoverride
reversed → Iterable<U>
An Iterable of the objects in this list in reverse order.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → U
Checks that this iterable has only one element, and returns that element.
no setteroverride
uiComponents → List<UIComponent?>

Available on Iterable<E>, provided by the UIIterableElementExtension extension

Returns a List of UIComponent of this Iterable of UIElements.
no setter

Methods

add(U element) → void
Adds value to the end of this list, extending the length by one.
inherited
addAll(Iterable<U> iterable) → void
Appends all objects of iterable to the end of this list.
inherited
addClass(String clazz) → void

Available on Iterable<E>, provided by the IterableDomElementExtension extension

Adds a class to all elements of this Iterable of Elements.
any(bool test(U element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
asMap() → Map<int, U>
An unmodifiable Map view of this list.
inherited
cast<R>() → List<R>
Returns a view of this list as a list of R instances.
inherited
clear() → void
Removes all objects from this list; the length of the list becomes zero.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → U
Returns the indexth element.
override
every(bool test(U element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> f(U element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
fillRange(int start, int end, [U? fill]) → void
Overwrites a range of elements with fillValue.
inherited
firstWhere(bool test(U element), {U orElse()?}) → U
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, U element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<U> other) → Iterable<U>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(U element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
getRange(int start, int end) → Iterable<U>
Creates an Iterable that iterates over a range of elements.
inherited
indexOf(Object? element, [int start = 0]) → int
The first index of element in this list.
inherited
indexWhere(bool test(U element), [int start = 0]) → int
The first index in the list that satisfies the provided test.
inherited
insert(int index, U element) → void
Inserts element at position index in this list.
inherited
insertAll(int index, Iterable<U> iterable) → void
Inserts all objects of iterable at position index in this list.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastIndexOf(Object? element, [int? start]) → int
The last index of element in this list.
inherited
lastIndexWhere(bool test(U element), [int? start]) → int
The last index in the list that satisfies the provided test.
inherited
lastWhere(bool test(U element), {U orElse()?}) → U
The last element that satisfies the given predicate test.
inherited
map<T>(T f(U element)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(U combine(U previousValue, U element)) → U
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
remove(Object? element) → bool
Removes the first occurrence of value from this list.
inherited
removeAt(int index) → U
Removes the object at position index from this list.
inherited
removeClass(String clazz) → void

Available on Iterable<E>, provided by the IterableDomElementExtension extension

Removes a class from all elements of this Iterable of Elements.
removeLast() → U
Removes and returns the last object in this list.
inherited
removeRange(int start, int end) → void
Removes a range of elements from the list.
inherited
removeWhere(bool test(U element)) → void
Removes all objects from this list that satisfy test.
inherited
replaceRange(int start, int end, Iterable<U> newContents) → void
Replaces a range of elements with the elements of replacements.
inherited
retainWhere(bool test(U element)) → void
Removes all objects from this list that fail to satisfy test.
inherited
selectAll(String? selectors) → List<Element>

Available on Iterable<Element>?, provided by the TestIterableElementExtension extension

setAll(int index, Iterable<U> iterable) → void
Overwrites elements with the objects of iterable.
inherited
setRange(int start, int end, Iterable<U> iterable, [int skipCount = 0]) → void
Writes some elements of iterable into a range of this list.
inherited
shuffle([Random? random]) → void
Shuffles the elements of this list randomly.
inherited
simplify({bool trim = true, bool collapseSpaces = true, bool lowerCase = true, String nullValue = ''}) → List<String>

Available on Iterable<UINode>?, provided by the TestIterableNodeExtension extension

simplifyAll({bool trim = true, bool collapseSpaces = true, bool lowerCase = true, String nullValue = '', String separator = ' , '}) → String

Available on Iterable<UINode>?, provided by the TestIterableNodeExtension extension

simplifyAt(int index, {bool trim = true, bool collapseSpaces = true, bool lowerCase = true, String nullValue = ''}) → String

Available on Iterable<UINode>?, provided by the TestIterableNodeExtension extension

simplifyFirst({bool trim = true, bool collapseSpaces = true, bool lowerCase = true, String nullValue = ''}) → String

Available on Iterable<UINode>?, provided by the TestIterableNodeExtension extension

simplifyLast({bool trim = true, bool collapseSpaces = true, bool lowerCase = true, String nullValue = ''}) → String

Available on Iterable<UINode>?, provided by the TestIterableNodeExtension extension

singleWhere(bool test(U element), {U orElse()?}) → U
The single element that satisfies test.
inherited
skip(int count) → Iterable<U>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(U element)) → Iterable<U>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
sort([int compare(U a, U b)?]) → void
Sorts this list according to the order specified by the compare function.
inherited
sublist(int start, [int? end]) → List<U>
Returns a new list containing the elements between start and end.
inherited
take(int count) → Iterable<U>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(U element)) → Iterable<U>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toElements() → List<Element>

Available on Iterable<Node>, provided by the IterableNodeExtension extension

toHTMLElements() → List<HTMLElement>

Available on Iterable<Node>, provided by the IterableNodeExtension extension

toList({bool growable = true}) → List<U>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<U>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
A string representation of this object.
inherited
where(bool test(U element)) → Iterable<U>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereElement() → Iterable<Element>

Available on Iterable<Node>, provided by the IterableNodeExtension extension

whereElementType<E extends Element>(Web<E> webType) → Iterable<E>

Available on Iterable<Node>, provided by the IterableNodeExtension extension

whereHTMLElement() → Iterable<HTMLElement>

Available on Iterable<Node>, provided by the IterableNodeExtension extension

whereType<T>() → Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited
withClass(String clazz) → List<E>

Available on Iterable<E>, provided by the IterableDomElementExtension extension

Filter elements with clazz.
withClasses(List<String> classes) → List<E>

Available on Iterable<E>, provided by the IterableDomElementExtension extension

Filter elements with all classes.
withID(String id) → List<E>

Available on Iterable<E>, provided by the IterableDomElementExtension extension

Filter elements with id.

Operators

operator +(List<U> other) → List<U>
Returns the concatenation of this list and other.
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → U
The object at the given index in the list.
override
operator []=(int index, U value) → void
Sets the value at the given index in the list to value.
override