JSONObject class abstract

Base class for an Object that can be converted to JSON.

Constructors

JSONObject()

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getObjectFields() → List<String>
Returns the names of the fields of this class.
inherited
getObjectFieldsDefault() → List<String>
Default implementation of getObjectFields.
inherited
getObjectValues() → List
Returns the values of the fields of this instance, in the same order of fields from getObjectFields.
inherited
initializeFromJson(String json) → void
Initializes this instance from a JSON String.
initializeFromMap(Map? jsonMap) → void
Initializes this instance from a Map.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setObjectValues(List values) → void
Sets this instances fields with values, in the same order of fields from getObjectFields.
inherited
toJson() → String
Converts this instance to a JSON String.
toMap() → Map<String, dynamic>
Converts this instance to a Map<String,dynamic>, containing the current fields values.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override