JSONTransformer class abstract

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setter

Methods

clearThen() → JSONTransformer
computeTransformation(Object? json) → dynamic
fromMatch(Match match) → JSONTransformer?
matches(String s) → Match?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
then(JSONTransformer? t1, [JSONTransformer? t2, JSONTransformer? t3, JSONTransformer? t4, JSONTransformer? t5, JSONTransformer? t6, JSONTransformer? t7, JSONTransformer? t8, JSONTransformer? t9, JSONTransformer? t10]) → JSONTransformer
Other JSONTransformer to apply after this transform.
thenChain(List<JSONTransformer>? then) → JSONTransformer
toString() → String
Returns this chain of operations as String.
override
toStringThen(String prefix) → String
transform(Object? json) → dynamic
Transforms json using chain operations.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(Object? transformers) → JSONTransformer?
Returns a JSONTransformer from transformers. Parses if needed.
parse(String? transformers) → JSONTransformer?
Parses transformers to a JSONTransformer chain.