Label<T extends num> class

Inheritance

Constructors

Label(String label, T left, T top, T width, T height, [Color? color])

Properties

bottom → T
The y-coordinate of the bottom edge.
no setterinherited
bottomLeft → Point<T>
no setterinherited
bottomRight → Point<T>
no setterinherited
color ↔ Color?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height → T
The height of the rectangle.
finalinherited
label → String
final
left → T
The x-coordinate of the left edge.
finalinherited
The x-coordinate of the right edge.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → T
The y-coordinate of the top edge.
finalinherited
topLeft → Point<T>
no setterinherited
topRight → Point<T>
no setterinherited
width → T
The width of the rectangle.
finalinherited

Methods

asMap() → Map
boundingBox(Rectangle<T> other) → Rectangle<T>
Returns a new rectangle which completely contains this and other.
inherited
containsPoint(Point<num> another) → bool
Tests whether another is inside or along the edges of this.
inherited
containsRectangle(Rectangle<num> another) → bool
Tests whether this entirely contains another.
inherited
intersection(Rectangle<T> other) → Rectangle<T>?
Computes the intersection of this and other.
inherited
intersects(Rectangle<num> other) → bool
Returns true if this intersects other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited