TBODYElement class

Inheritance

Constructors

TBODYElement({Map<String, dynamic>? attributes, Object? id, Object? classes, Object? style, Object? rows, bool? hidden, bool commented = false})

Properties

allowContent → bool
Indicates if this node accepts content.
finalinherited
asDOMElement → DOMElement
no setterinherited
asDOMNode → DOMNode
no setterinherited
attributes → Map<String, dynamic>
no setterinherited
attributesAsString → Map<String, String>
no setterinherited
attributesLength → int
Returns the size of attributes Map.
no setterinherited
attributesNames → Iterable<String>
Returns the attributes names with values.
no setterinherited
classes ↔ String?
Returns the attribute class.
getter/setter pairinherited
classesList ↔ List<String>
Returns the list of class names of the attribute class.
getter/setter pairinherited
commented ← bool
no getterinherited
content → List<DOMNode>?
Actual list of nodes that represents the content of this node.
no setterinherited
domAttributes → Map<String, DOMAttribute>
no setterinherited
domGenerator → DOMGenerator<Object>?
Returns the DOMGenerator associated with treeMap.
no setterinherited
hasAnyEventListener → bool
True when at least one event callback is attached.
no setterinherited
hasAttributes → bool
Returns true if this element has attributes.
no setterinherited
hasEmptyAttributes → bool
Returns true if this element has NO attributes.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasOnChangeListener → bool
Returns true if has any onChange listener registered.
no setterinherited
hasOnClickListener → bool
Returns true if has any onClick listener registered.
no setterinherited
hasOnErrorListener → bool
Returns true if has any onError listener registered.
no setterinherited
hasOnGenerateListener → bool
Returns true if has any onGenerate listener registered.
no setterinherited
hasOnKeyDownListener → bool
Returns true if has any onKeyDown listener registered.
no setterinherited
hasOnKeyPressListener → bool
Returns true if has any onKeyPress listener registered.
no setterinherited
hasOnKeyUpListener → bool
Returns true if has any onKeyUp listener registered.
no setterinherited
hasOnLoadListener → bool
Returns true if has any onLoad listener registered.
no setterinherited
hasOnlyElementNodes → bool
Returns true if this node content is empty (no children nodes). Returns ![isEmpty]. Returns true if this node only have DOMElement nodes.
no setterinherited
hasOnlyTextNodes → bool
Returns true if this node only have TextNode nodes.
no setterinherited
hasOnMouseOutListener → bool
Returns true if has any onMouseOut listener registered.
no setterinherited
hasOnMouseOverListener → bool
Returns true if has any onMouseOver listener registered.
no setterinherited
hasParent → bool
Returns true if this node has a parent.
no setterinherited
hasTemplate → bool
Returns true if this node has a DOMTemplate.
no setterinherited
hasUnresolvedTemplate → bool
Returns true if this node has a text node with a unresolved DOMTemplate.
no setterinherited
hasValue → bool
Returns true if has value.
no setterinherited
id → String?
Returns the attribute id.
no setterinherited
indexInParent → int
Returns the index position of this node in the parent.
no setterinherited
isCommented → bool
If true this node is commented (ignored).
no setterinherited
isEmptyContent → bool
Returns true if this node content is empty (no children nodes).
no setterinherited
isGenerated → bool
Returns true if this node has a generated element by domGenerator.
no setterinherited
isNotEmptyContent → bool
Returns true if this node content is NOT empty (has children nodes). See isEmptyContent.
no setterinherited
isStringElement → bool
Returns true if this element is a TextNode or a DOMElement of tag: sup, i, em, u, b, strong.
no setterinherited
isWhiteSpaceContent → bool
Returns true if this node only have white space content.
no setterinherited
length → int
Returns the total number of children nodes.
no setterinherited
nodes → List<DOMNode>
Returns a copy List of children nodes.
no setterinherited
nodesView → List<DOMNode>
Same as nodes but returns an unmodifiable List.
no setterinherited
onChange → EventStream<DOMEvent<Object>>
Event handler for change events.
no setterinherited
onClick → EventStream<DOMMouseEvent<Object>>
Event handler for click events.
no setterinherited
onError → EventStream<DOMEvent<Object>>
Event handler for load events.
no setterinherited
onGenerate → EventStream<Object>
Event handler for when this element is generated by DOMGenerator.
no setterinherited
onKeyDown → EventStream<DOMEvent<Object>>
Event handler for change events.
no setterinherited
onKeyPress → EventStream<DOMEvent<Object>>
Event handler for change events.
no setterinherited
onKeyUp → EventStream<DOMEvent<Object>>
Event handler for change events.
no setterinherited
onLoad → EventStream<DOMEvent<Object>>
Event handler for load events.
no setterinherited
onMouseOut → EventStream<DOMMouseEvent<Object>>
Event handler for click mouseOut events.
no setterinherited
onMouseOver → EventStream<DOMMouseEvent<Object>>
Event handler for click mouseOver events.
no setterinherited
parent ↔ DOMNode?
Returns the parent DOMNode of generated tree (by DOMGenerator).
getter/setter pairinherited
possibleAttributes → Map<String, String>
Map of possible attributes for this element.
no setterinherited
root → DOMNode
Returns the root DOMNode of this element. If this node doesn't have a parent, will return this instance as root.
no setterinherited
runtime → DOMNodeRuntime<Object>
Returns a DOMNodeRuntime with the actual generated node associated with treeMap and domGenerator.
no setterinherited
runtimeNode → dynamic
Returns runtime.node.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ CSS
Returns the attribute style as CSS.
getter/setter pairinherited
styleText ↔ String?
getter/setter pairinherited
tag → String
The tag name in lower-case.
finalinherited
text → String
Returns the content of this node as text.
no setterinherited
treeMap ↔ DOMTreeMap<Object>?
Returns the DOMTreeMap of the last generated tree of elements.
getter/setter pairinherited
value → String?
no setterinherited
valueAsBool → bool?
Returns value as bool.
no setterinherited
valueAsDouble → double?
Returns value as double.
no setterinherited
valueAsInt → int?
Returns value as bool.
no setterinherited
valueAsNum → num?
Returns value as num.
no setterinherited

Methods

absorbNode(DOMNode other) → bool
Absorb the content of other and appends to this node.
inherited
add(Object? entry) → DOMElement
inherited
addAll(Iterable? entries) → DOMNode
Adds all entries to children nodes.
inherited
addAllAttributes(Map<String, dynamic>? attributes) → DOMElement
Add attributes to this instance.
inherited
addAsTag<T>(String tag, T entry, [ContentGenerator<T>? contentGenerator]) → DOMNode
inherited
addClass(String className) → void
Adds a className to attribute class.
inherited
addEach<T>(Iterable<T> iterable, [ContentGenerator<T>? contentGenerator]) → DOMElement
Adds each entry of iterable to content.
inherited
addEachAsTag<T>(String tag, Iterable<T> iterable, [ContentGenerator<T>? contentGenerator]) → DOMElement
inherited
addHTML(String html) → DOMElement
Parses html and add it to content.
inherited
allEventHandlers() → List<EventStream>
Returns all currently initialized event handlers.
inherited
appendToAttribute(String name, Object? value) → DOMElement
Appends value to attribute of name. Useful for attributes like class and style.
inherited
apply<T extends DOMElement>({dynamic id, dynamic classes, dynamic style}) → T
Applies id, classes and style to this instance.
inherited
applyWhere<T extends DOMElement>(Object? selector, {dynamic id, dynamic classes, dynamic style}) → T
Applies id, classes and style to children nodes that matches selector.
inherited
buildCloseTagHTML() → String
inherited
buildDOM<T extends Object>({DOMGenerator<T>? generator, DOMTreeMap<T>? treeMap, T? parent, DOMContext<T>? context, bool setTreeMapRoot = true}) → T?
Builds a DOM using generator.
inherited
buildHTML({bool withIndent = false, String parentIndent = '', String indent = ' ', bool disableIndent = false, bool xhtml = false, DSXResolution dsxResolution = DSXResolution.skipDSX, bool buildTemplates = false, DOMNode? parentNode, DOMNode? previousNode, DOMContext<Object>? domContext}) → String
Generates a HTML from this node tree.
inherited
buildHTMLContent({bool withIndent = false, String indent = ' ', bool disableIndent = false, bool xhtml = false, DSXResolution dsxResolution = DSXResolution.skipDSX, bool buildTemplates = false, String innerIndent = '', String innerBreakLine = '', DOMNode? parentNode, DOMNode? previousNode, DOMContext<Object>? domContext, StringBuffer? output}) → StringBuffer
inherited
buildOpenTagHTML({bool openCloseTag = false, DSXResolution dsxResolution = DSXResolution.skipDSX, DOMContext<Object>? domContext}) → String
inherited
catchNodesWhere<T extends DOMNode>(Object? selector, List<T> destiny) → void
inherited
checkNodes() → void
Checks children nodes integrity.
inherited
clearNodes() → void
Clear the children list.
inherited
closeAllEventHandlers() → Future<int>
Closes and removes all attached event handlers.
inherited
containsAllClasses(Iterable<String>? classes) → bool
Returns true if attribute class has all classes.
inherited
containsAnyClass(Iterable<String>? classes) → bool
Returns true if attribute class has any of classes.
inherited
containsAttribute(String attributeName) → bool
inherited
containsClass(String className) → bool
Returns true if attribute class has the className.
inherited
containsNode(DOMNode node, {dynamic deep = true}) → bool
Returns true if node is a child of this node.
inherited
copy() → TBODYElement
Copies this node.
override
copyContent() → List<DOMNode>
Copies this node content.
inherited
duplicate() → DOMNode?
Duplicate this node and add it to the parent.
inherited
duplicateNode(DOMNode node) → DOMNode?
Duplicate node and add it to the children list.
inherited
equals(Object other) → bool
Returns true if other is fully equals.
inherited
equalsAttributes(DOMElement other) → bool
Returns true if other have the same attributes.
inherited
getAttribute(String name) → DOMAttribute?
Returns DOMAttribute entry for name.
inherited
getAttributesSignature() → String
Returns a deterministic String of all attributes entries.
inherited
getAttributeValue(String name, [DOMContext<Object>? domContext]) → String?
Returns attribute value for name.
inherited
getAttributeValueAsBool(String name, [DOMContext<Object>? domContext]) → bool
Calls getAttributeValue and returns parsed as bool.
inherited
getAttributeValueAsDouble(String name, [DOMContext<Object>? domContext]) → double?
Calls getAttributeValue and returns parsed as double.
inherited
getAttributeValueAsInt(String name, [DOMContext<Object>? domContext]) → int?
Calls getAttributeValue and returns parsed as int.
inherited
getRuntime<T extends Object>() → DOMNodeRuntime<T>
Same as runtime, but casted to DOMNodeRuntime<T>.
inherited
getRuntimeNode<T>() → T?
Same as runtimeNode, but casts to T.
inherited
hasAttributeValue(String name, [DOMContext<Object>? domContext]) → bool
Returns true if attribute for name exists.
inherited
hasFutureElement({bool recursive = false}) → bool
Returns true if this node contains any Future element.
inherited
indexOf(Object? selector) → int
Returns the index of a child node that matches selector.
inherited
indexOfNode(DOMNode node) → int
Returns the index of node.
inherited
indexOfNodeIdentical(DOMNode node) → int
inherited
indexOfNodeIdenticalFirst(DOMNode node) → int
inherited
indexOfNodeWhere(bool test(DOMNode other)) → int
inherited
insertAfter(Object? indexSelector, Object? entry) → DOMElement
Inserts entry after index of child node that matches indexSelector.
inherited
insertAt(Object? indexSelector, Object? entry) → DOMElement
Inserts entry at index of child node that matches indexSelector.
inherited
isCompatibleForMerge(DOMNode other) → bool
Returns true if other is compatible to call merge.
inherited
isConsecutiveNode(DOMNode other) → bool
Returns true if other is the previous or next sibling of this node parent.
inherited
isInSameParent(DOMNode other) → bool
Returns true if other is in the same parent of this node.
inherited
isNextNode(DOMNode other) → bool
Returns true if other is the next sibling of this node parent.
inherited
isPreviousNode(DOMNode other) → bool
Returns true if other is the previous sibling of this node parent.
inherited
isTagOneOf(Iterable<String> tags) → bool
Returns true if tag is one of tags.
inherited
merge(DOMNode other, {bool onlyConsecutive = true}) → bool
Merges this node with other. Useful for consecutive text elements like b, i and span.
inherited
moveDown() → bool
Moves this node down in the parent children list.
inherited
moveDownNode(DOMNode node) → bool
Moves node down in the children list.
inherited
moveUp() → bool
Moves this node up in the parent children list.
inherited
moveUpNode(DOMNode node) → bool
Moves node up in the children list.
inherited
node<T extends DOMNode>(Object? selector) → T?
inherited
nodeByID<T extends DOMNode>(String? id) → T?
Returns a child node by id.
inherited
nodeByIndex<T extends DOMNode>(int? index) → T?
Returns a child node by index.
inherited
nodeEquals<T extends DOMNode>(DOMNode? node) → T?
Returns a node T that is equals to node.
inherited
nodesWhere<T extends DOMNode>(Object? selector) → List<T>
Returns a List<T> of children nodes that matches selector.
inherited
nodeWhere<T extends DOMNode>(Object? selector) → T?
inherited
normalizeContent() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyElementGenerated(Object element) → void
Dispatch a onGenerate event with element.
inherited
putDOMAttribute(DOMAttribute attribute) → DOMElement
inherited
remove() → bool
Removes this node from parent.
inherited
removeAttribute(String attributeName) → bool
inherited
removeAttributeDeeply(String attributeName) → bool
inherited
removeNode(DOMNode node) → bool
Removes node from children list.
inherited
resolvedDSXs() → Iterable<DSX<Object>>
inherited
resolveDSX() → void
inherited
select<T extends DOMNode>(Object? selector) → T?
Returns a node T that matches selector.
inherited
selectAllByType<T extends DOMNode>() → List<T>
Returns a List<T> of children nodes that are of type T.
inherited
selectAllWhere<T extends DOMNode>(Object? selector) → List<T>
Returns a List<T> of children nodes that matches selector.
inherited
selectByID<T extends DOMNode>(String? id) → T?
Returns a node T that has attribute id.
inherited
selectByTag<T extends DOMNode>(List<String>? tags) → T?
Returns a node T that is one of tags.
inherited
selectByType<T extends DOMNode>() → T?
Returns a child node of type T.
inherited
selectEquals<T extends DOMNode>(DOMNode? node) → T?
inherited
selectParentWhere<T extends DOMNode>(Object? selector) → T?
Returns a parent T that matches selector.
inherited
selectWhere<T extends DOMNode>(Object? selector) → T?
Returns a T child node that matches selector.
inherited
selectWithAllClasses<T extends DOMNode>(List<String>? classes) → T?
Returns a node T that has all classes.
inherited
selectWithAnyClass<T extends DOMNode>(List<String>? classes) → T?
Returns a node T that has any of classes.
inherited
setAttribute(String name, Object? value) → DOMElement
Sets attribute for name, parsing value.
inherited
setAttributeIfAbsent(String name, Object? value) → DOMElement
inherited
setContent(Object? newContent) → DOMElement
Sets the content of this node.
inherited
toString() → String
A string representation of this object.
inherited
validator(Function validator, {String? errorClass, String? validClass}) → StreamSubscription<DOMEvent<Object>>
Sets the validator of this DOMElement.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String name) → String?
inherited
operator []=(String name, Object? value) → void
inherited

Static Methods

from(Object? entry) → TBODYElement?
Creates a DOMNode from dynamic parameter entry.
override