TOperation class abstract

Base class for operations.

Inheritance

Constructors

TOperation(String name, bool nonCollectionOperation, [List? parameters])

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the operation, like a method name.
final
nonCollectionOperation → bool
final
parameters → List?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setteroverride

Methods

clearThen() → JSONTransformer
inherited
computeOperation(Object? json) → dynamic
computeTransformation(Object? json) → dynamic
override
fromMatch(Match match) → TOperation
override
fromParameters([List? parameters]) → TOperation
getParameter<T>(int index, [T? def, T parser(Object v)?]) → T?
matches(String s) → Match?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parametersToString() → String
parseParameters(String? s) → List?
subParameters(int offset) → List?
then(JSONTransformer? t1, [JSONTransformer? t2, JSONTransformer? t3, JSONTransformer? t4, JSONTransformer? t5, JSONTransformer? t6, JSONTransformer? t7, JSONTransformer? t8, JSONTransformer? t9, JSONTransformer? t10]) → JSONTransformer
Other JSONTransformer to apply after this transform.
inherited
thenChain(List<JSONTransformer>? then) → JSONTransformer
inherited
toString() → String
Returns this chain of operations as String.
override
toStringThen(String prefix) → String
inherited
transform(Object? json) → dynamic
Transforms json using chain operations.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

OPS_PATTERN → Map<String, RegExp>
final