TextStyle class

Specifies a CSS text style.

Implemented types

Constructors

TextStyle({StyleColor? color, StyleColor? backgroundColor, FontStyle? fontStyle, FontWeight? fontWeight, StyleColor? borderColor, String? borderRadius, String? padding})
const

Properties

backgroundColor → StyleColor?
final
borderColor → StyleColor?
final
borderRadius → String?
final
color → StyleColor?
final
fontStyle → FontStyle?
final
fontWeight → FontWeight?
final
hashCode → int
The hash code for this object.
no setterinherited
padding → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cssValue() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited