UITestContext<U extends UIRoot> class

The context of a testUI execution.

Constructors

UITestContext(String testUIName, {int testUIId = 0})

Properties

channel → StreamChannel?
The StreamChannel if a spawnHybridUri is passed to testUI.
no setter
document → UITestChainNode<U, Element, UITestChainRoot<U>>
no setter
errors → UnmodifiableListView<Object>
Returns the current testUI errors.
no setter
hasErrors → bool
Returns true if the current testUI has errors.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isInitialized → bool
Returns true if uiRoot was initialized.
no setter
root → UITestChainRoot<U>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testUIId → int
final
testUIName → String
final
uiRoot → U
The instantiated UIRoot for the test.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setTestWindowTitle([String? step]) → void
Sets the test window title.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited