Viewport class

Represents browser window Viewport.

Constructors

Viewport(int width, int height, [int? deviceWidth, int? deviceHeight])

Properties

deviceHeight ↔ int
The device height.
getter/setter pair
deviceWidth ↔ int
The device width.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
height ↔ int
The Viewport height.
getter/setter pair
heightAsPx → String
Returns height as a px String.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vmax → int
The biggest side of the viewport: Math.max(width, height)
no setter
vmaxAsPx → String
Returns vmax as a px String.
no setter
vmin → int
The smallest side of the viewport: Math.min(width, height)
no setter
vminAsPx → String
Returns vmin as a px String.
no setter
width ↔ int
The Viewport width.
getter/setter pair
widthAsPx → String
Returns width as a px String.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override