WithValue mixin

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasValue → bool
Returns true if has value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
no setter
valueAsBool → bool?
Returns value as bool.
no setter
valueAsDouble → double?
Returns value as double.
no setter
valueAsInt → int?
Returns value as bool.
no setter
valueAsNum → num?
Returns value as num.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited