BonesUITestRunner class

A Bones_UI test runner.

Constructors

BonesUITestRunner({List<String>? args, Directory? compileDir, String bonesUITestConfigFileName = 'bones_ui_test_config.yaml', String bonesUITestTemplateFileName = 'bones_ui_test.html.tpl'})

Properties

allKnownPlatforms → List<String>
Returns all the known platforms for the test package.
no setter
args ↔ List<String>
The original arguments.
latefinal
bonesUICompileDir → Directory
no setter
bonesUICompiler → BonesUICompiler
final
bonesUiTestConfigFile ↔ File
The Bones_UI test config file. Default: bones_ui_test_config.yaml
latefinal
bonesUITestTemplateFile → File
no setter
bonesUITestTemplateFileName → String
The Bones_UI test template HTML file. Default: bones_ui_test.html.tpl
final
debug → bool
Returns true if in debug mode.
no setter
enableDeferredLibraries ↔ bool?
If defined, enables/disables deferred libraries.
latefinal
hashCode → int
The hash code for this object.
no setterinherited
headless → bool
Returns true if running the browser in headless mode.
no setter
jsonReportFilePath → String?
no setter
logDirectory ↔ Directory?
The Directory to save the test logs and reports.
latefinal
parsedArgs ↔ Configuration
The parsed test arguments.
latefinal
parsedArgsPlatform → String?
The parsed --platform parameter.
no setter
pauseAfterLoad → bool
Returns trur if --pause-after-load was passed.
no setter
platform → String
The selected platform to run the tests.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showUI ↔ bool
Returns true if --show-ui was passed.
latefinal

Methods

buildBonesUITestConfig(bool includeDartTestConfig, File dartTestConfigFile) → String
Builds the bonesUiTestConfigFile content.
buildTestTemplateFile() → String
execute() → Future<bool>
Executes the tests.
generateBonesUITestConfigFile() → void
Generates the
generateTestTemplateFile() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepare() → Future<void>
printTestInfo(Iterable jsons) → void
resolveTestArgs() → List<String>
Resolves the test args to pass to the test package.
resolveTestConfigurationPath(Configuration testConfiguration) → String
Resolves the test configuration path. Defaults to bonesUiTestConfigFile.
showHelp() → Future<bool>
Shows the usage help in the console.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited