CalendarEvent class
- Implemented types
Constructors
- CalendarEvent(String title, DateTime initTime, DateTime endTime, {String? description})
- CalendarEvent.byDuration(String title, DateTime initTime, Duration duration, {String? description})
-
CalendarEvent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description ↔ String
-
getter/setter pair
- duration → Duration
-
no setter
- endTime ↔ DateTime
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- initTime ↔ DateTime
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String
-
getter/setter pair
Methods
-
compareTo(
CalendarEvent other) → int -
Compares this object to another object.
override
-
isInTimeRange(
DateTime init, DateTime end) → bool -
Returns
trueif this event is entirely insideinit..end. See overlapsTimeRange. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overlapsTimeRange(
DateTime init, DateTime end) → bool -
Returns
trueif this event overlaps the time rangeinit..end(endexclusive): it starts beforeendand ends afterinit. An instant event (initTime == endTime) overlaps if it's in the range. -
render(
{bool continued = false}) → DIVElement -
Renders this event.
continuedrenders it as the continuation of an event that started in a previous time range (classui-calendar-event-continuation). -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited