UINavigator class
Handles navigation and routes.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
- Removes from navigables cache detached elements.
-
Find in
elementtree nodes with attributenavigate. -
Finds a UINavigableComponent that responds for
route. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
- Refreshed the current route.
- Refreshed the current route asynchronously.
- Registers a UINavigableComponent.
- Returns List<UIElement> that are from navigable components.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
Returns the current Navigation.
no setter
- currentRoute → String?
-
Returns the current route.
no setter
-
currentRouteParameters
→ Map<
String, String> ? -
Returns the current route parameters.
no setter
- hasRoute → bool
-
Returns
trueif current location has a route entry.no setter -
Returns the initial Navigation when browser window was open.
no setter
- initialRoute → String?
-
Returns the initial route when browser window was open.
no setter
- isOffline → bool
-
Returns
trueif this device is off-line.no setter - isOnline → bool
-
Returns
trueif this device is online.no setter - isSecureContext → bool
-
Returns
trueif this device is in secure contexts (HTTPS).no setter -
Returns all the known routes of registered navigables.
no setter
-
no setter
-
no setter
-
Returns a history list of Navigation.
no setter
-
EventStream for when navigation changes. Passes route name.
no setter
- urlFilter ↔ String Function(String a)?
-
getter/setter pair
Static Methods
-
equalsToCurrentRoute(
String route, {Map< String, String> ? parameters}) → bool -
Returns
trueifrouteequals to currentRoute. -
equalsToCurrentRouteParameters(
Map< String, String> ? parameters) → bool -
Returns
trueifparametersare equals to currentRouteParameters. -
get(
) → UINavigator -
getCurrentRoute(
{String defaultRoute = ''}) → String -
Returns the currentRoute or
defaultRoute. -
Returns the current
navigateproperty ofelement. -
Navigate using
navigationdo determine route and parameters. -
Navigate asynchronously using
navigationdo determine route and parameters. -
Register a
onClicklistener inelementto navigate toroutewithparameters. -
Navigate to a
routewithparametersorparametersProvider. -
Navigate asynchronously to a
routewithparametersorparametersProvider. -
Navigates to a main route (
mainRouteLoggedormainRouteNotLogged) based inisLoggedstatus andisLoggedRouteandisNotLoggedRoutecheckers.