navigateToAsync static method
void
navigateToAsync(
Navigate asynchronously to a route with parameters or parametersProvider.
force If true changes the route even if the current route is the same.
Implementation
static void navigateToAsync(String? route,
{Map<String, String>? parameters,
ParametersProvider? parametersProvider,
bool force = false}) {
get()._callNavigateToAsync(route, parameters, parametersProvider, force);
}