debug property
Enables debug mode.
When true, created wrappers retain a weak reference to the
associated key, allowing inspection for memory leak analysis.
When false, a minimal wrapper is used.
Implementation
final bool debug;
Enables debug mode.
When true, created wrappers retain a weak reference to the
associated key, allowing inspection for memory leak analysis.
When false, a minimal wrapper is used.
final bool debug;