debug property
Enables debug mode.
When true, wrappers retain an additional weak reference to the
associated key, allowing inspection for memory leak analysis.
When false, a lighter wrapper is used.
Implementation
final bool debug;
Enables debug mode.
When true, wrappers retain an additional weak reference to the
associated key, allowing inspection for memory leak analysis.
When false, a lighter wrapper is used.
final bool debug;