FinalizerCallback<V> typedef
FinalizerCallback<V> =
void Function(V value)
Signature for a callback invoked when a key associated with a finalizer becomes unreachable.
The provided value corresponds to the value previously associated
with the collected key.
Implementation
typedef FinalizerCallback<V> = void Function(V value);